--- gtk+-2.24.33/gtk/gtkfilesel.c.orig
+++ gtk+-2.24.33/gtk/gtkfilesel.c
@@ -79,6 +79,9 @@
 #include "gtkdnd.h"
 #include "gtkeventbox.h"
 #include "gtkoptionmenu.h"
+#include "gtkimage.h"
+
+#include "stock-icons/sun-icons.h"
 
 #define WANT_HPANED 1
 #include "gtkhpaned.h"
@@ -318,6 +321,9 @@
  */
 static gchar*              cmpl_completion_fullname (const gchar*, CompletionState* cmpl_state);
 
+static void home_clicked (GtkWidget *widget, gpointer data);
+static void desktop_clicked (GtkWidget *widget, gpointer data);
+static void documents_clicked (GtkWidget *widget, gpointer data);
 
 /* Directory operations. */
 static CompletionDir* open_ref_dir         (gchar* text_to_complete,
@@ -627,6 +633,10 @@
   GtkWidget *spacer;
   GtkDialog *dialog;
 
+  GdkPixbuf *ipixbuf;
+  GtkWidget *bbox, *home_button, *desk_button, *docs_button, *xbox;
+  GtkWidget *lbox;
+
   GtkListStore *model;
   GtkTreeViewColumn *column;
   
@@ -640,18 +650,9 @@
   filesel->main_vbox = dialog->vbox;
   gtk_container_set_border_width (GTK_CONTAINER (filesel), 10);
 
-  /* The horizontal box containing create, rename etc. buttons */
-  filesel->button_area = gtk_hbutton_box_new ();
-  gtk_button_box_set_layout (GTK_BUTTON_BOX (filesel->button_area), GTK_BUTTONBOX_START);
-  gtk_box_set_spacing (GTK_BOX (filesel->button_area), 0);
-  gtk_box_pack_start (GTK_BOX (filesel->main_vbox), filesel->button_area, 
-		      FALSE, FALSE, 0);
-  gtk_widget_show (filesel->button_area);
-  
-  gtk_file_selection_show_fileop_buttons (filesel);
-
   /* hbox for pulldown menu */
   pulldown_hbox = gtk_hbox_new (TRUE, 5);
+  gtk_container_set_border_width (GTK_CONTAINER (pulldown_hbox), 4);
   gtk_box_pack_start (GTK_BOX (filesel->main_vbox), pulldown_hbox, FALSE, FALSE, 0);
   gtk_widget_show (pulldown_hbox);
   
@@ -663,14 +664,27 @@
     
   /*  The horizontal box containing the directory and file listboxes  */
 
+  xbox = gtk_hbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (filesel->main_vbox), xbox, TRUE, TRUE, 0);
+  gtk_widget_show (xbox);
+
+  bbox = gtk_vbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (xbox), bbox, FALSE, FALSE, 5);
+  gtk_widget_show (bbox);
+
+  lbox = gtk_vbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (xbox), lbox, TRUE, TRUE, 5);
+  gtk_widget_show (lbox);
+
   spacer = gtk_hbox_new (FALSE, 0);
   gtk_widget_set_size_request (spacer, -1, 5);
-  gtk_box_pack_start (GTK_BOX (filesel->main_vbox), spacer, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (lbox), spacer, FALSE, FALSE, 0);
   gtk_widget_show (spacer);
   
   list_hbox = gtk_hbox_new (FALSE, 5);
-  gtk_box_pack_start (GTK_BOX (filesel->main_vbox), list_hbox, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (lbox), list_hbox, TRUE, TRUE, 0);
   gtk_widget_show (list_hbox);
+
   if (WANT_HPANED)
     list_container = g_object_new (GTK_TYPE_HPANED,
 				   "visible", TRUE,
@@ -682,9 +696,81 @@
 
   spacer = gtk_hbox_new (FALSE, 0);
   gtk_widget_set_size_request (spacer, -1, 5);
-  gtk_box_pack_start (GTK_BOX (filesel->main_vbox), spacer, FALSE, FALSE, 0);  
+  gtk_box_pack_start (GTK_BOX (lbox), spacer, FALSE, FALSE, 0);  
   gtk_widget_show (spacer);
   
+
+  /* The Pretty Icons */
+  
+  docs_button = gtk_button_new ();
+  gtk_container_set_border_width (GTK_CONTAINER (docs_button), 4);
+  gtk_box_pack_start (GTK_BOX (bbox), docs_button, FALSE, FALSE, 0);
+  gtk_widget_show (docs_button);
+
+  g_signal_connect (G_OBJECT (docs_button), "clicked",
+                   G_CALLBACK (documents_clicked), filesel);
+
+  xbox = gtk_vbox_new (FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (docs_button), xbox);
+  gtk_widget_show (xbox);
+
+  ipixbuf = gdk_pixbuf_new_from_inline (-1, stock_documents_48, FALSE, NULL);
+  label = gtk_image_new_from_pixbuf (ipixbuf);
+  gtk_box_pack_start (GTK_BOX (xbox), label, FALSE, FALSE, 0);
+  gtk_widget_show (label);
+
+  /* SUN_BRANDING */
+  label = gtk_label_new_with_mnemonic (_("_Documents"));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), docs_button);
+  gtk_box_pack_end (GTK_BOX (xbox), label, FALSE, FALSE, 0);
+  gtk_widget_show (label);
+  
+  desk_button = gtk_button_new ();
+  gtk_container_set_border_width (GTK_CONTAINER (desk_button), 4);
+  gtk_box_pack_start (GTK_BOX (bbox), desk_button, FALSE, FALSE, 0);
+  gtk_widget_show (desk_button);
+
+  g_signal_connect (G_OBJECT (desk_button), "clicked",
+		    G_CALLBACK (desktop_clicked), filesel);
+
+  xbox = gtk_vbox_new (FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (desk_button), xbox);
+  gtk_widget_show (xbox);
+
+  ipixbuf = gdk_pixbuf_new_from_inline (-1, stock_desktop_48, FALSE, NULL);
+  label = gtk_image_new_from_pixbuf (ipixbuf);
+  gtk_box_pack_start (GTK_BOX (xbox), label, FALSE, FALSE, 0);
+  gtk_widget_show (label);
+
+  /* SUN_BRANDING */
+  label = gtk_label_new_with_mnemonic (_("D_esktop"));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), desk_button);
+  gtk_box_pack_end (GTK_BOX (xbox), label, FALSE, FALSE, 0);
+  gtk_widget_show (label);
+
+  home_button = gtk_button_new ();
+  gtk_container_set_border_width (GTK_CONTAINER (home_button), 4);
+  gtk_box_pack_start (GTK_BOX (bbox), home_button, FALSE, FALSE, 0);
+  gtk_widget_show (home_button);
+
+  g_signal_connect (G_OBJECT (home_button), "clicked",
+                   G_CALLBACK (home_clicked), filesel);
+
+  xbox = gtk_vbox_new (FALSE, 0);
+  gtk_container_add (GTK_CONTAINER (home_button), xbox);
+  gtk_widget_show (xbox);
+
+  ipixbuf = gdk_pixbuf_new_from_inline (-1, stock_home_48, FALSE, NULL);
+  label = gtk_image_new_from_pixbuf (ipixbuf);
+  gtk_box_pack_start (GTK_BOX (xbox), label, FALSE, FALSE, 0);
+  gtk_widget_show (label);
+
+  /* SUN_BRANDING */
+  label = gtk_label_new_with_mnemonic (_("_Home"));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label), home_button);
+  gtk_box_pack_end (GTK_BOX (xbox), label, FALSE, FALSE, 0);
+  gtk_widget_show (label);
+
   /* The directories list */
 
   model = gtk_list_store_new (1, G_TYPE_STRING);
@@ -757,6 +843,15 @@
   gtk_widget_show (filesel->file_list);
   gtk_widget_show (scrolled_win);
 
+  /* The horizontal box containing create, rename etc. buttons */
+  filesel->button_area = gtk_hbox_new (FALSE, 0);
+  gtk_box_set_spacing (GTK_BOX (filesel->button_area), 0);
+  gtk_box_pack_start (GTK_BOX (lbox), filesel->button_area, 
+		      FALSE, FALSE, 0);
+  gtk_widget_show (filesel->button_area);
+  
+  gtk_file_selection_show_fileop_buttons (filesel);
+
   /* action area for packing buttons into. */
   filesel->action_area = gtk_hbox_new (TRUE, 0);
   gtk_box_pack_start (GTK_BOX (filesel->main_vbox), filesel->action_area, 
@@ -1012,39 +1107,94 @@
 void
 gtk_file_selection_show_fileop_buttons (GtkFileSelection *filesel)
 {
+  GtkWidget *label;
+  GtkWidget *bbox;
+  
   g_return_if_fail (GTK_IS_FILE_SELECTION (filesel));
     
   /* delete, create directory, and rename */
   if (!filesel->fileop_c_dir) 
     {
-      filesel->fileop_c_dir = gtk_button_new_with_mnemonic (_("_New Folder"));
+      filesel->fileop_c_dir = gtk_button_new ();
+      gtk_container_set_border_width (GTK_CONTAINER (filesel->fileop_c_dir), 4);
+      
+      bbox = gtk_hbox_new (FALSE, 2);
+      gtk_container_add (GTK_CONTAINER (filesel->fileop_c_dir), bbox);
+      
+      label = gtk_image_new_from_stock (GTK_STOCK_OPEN, GTK_ICON_SIZE_BUTTON);
+      gtk_box_pack_start (GTK_BOX (bbox), label, FALSE, FALSE, 0);
+      gtk_widget_show (label);
+      
+      label = gtk_label_new_with_mnemonic (_("_New Folder"));
+      gtk_label_set_mnemonic_widget (GTK_LABEL (label), filesel->fileop_c_dir);
+      gtk_box_pack_start (GTK_BOX (bbox), label, FALSE, FALSE, 0);
+      gtk_widget_show (label);
+      
+      gtk_widget_show (bbox);
+      
       g_signal_connect (filesel->fileop_c_dir, "clicked",
-			G_CALLBACK (gtk_file_selection_create_dir),
-			filesel);
+			G_CALLBACK (gtk_file_selection_create_dir), 
+			(gpointer) filesel);
       gtk_box_pack_start (GTK_BOX (filesel->button_area), 
-			  filesel->fileop_c_dir, TRUE, TRUE, 0);
+			  filesel->fileop_c_dir, FALSE, FALSE, 0);
       gtk_widget_show (filesel->fileop_c_dir);
     }
-	
+  
   if (!filesel->fileop_del_file) 
     {
-      filesel->fileop_del_file = gtk_button_new_with_mnemonic (_("De_lete File"));
+      filesel->fileop_del_file = gtk_button_new ();
+      gtk_container_set_border_width (GTK_CONTAINER (filesel->fileop_del_file), 4);
+      
+      bbox = gtk_hbox_new (FALSE, 2);
+      gtk_container_add (GTK_CONTAINER (filesel->fileop_del_file), bbox);
+      
+      label = gtk_image_new_from_stock (GTK_STOCK_DELETE,
+ 					GTK_ICON_SIZE_BUTTON);
+      gtk_box_pack_start (GTK_BOX (bbox), label, FALSE, FALSE, 0);
+      gtk_widget_show (label);
+      
+      label = gtk_label_new (_("De_lete File"));
+      gtk_label_set_use_underline (GTK_LABEL (label), TRUE);
+      gtk_label_set_mnemonic_widget (GTK_LABEL (label), filesel->fileop_del_file);
+      gtk_box_pack_start (GTK_BOX (bbox), label, FALSE, FALSE, 0);
+      gtk_widget_show (label);
+      
+      gtk_widget_show (bbox);
+      
       g_signal_connect (filesel->fileop_del_file, "clicked",
 			G_CALLBACK (gtk_file_selection_delete_file),
-			filesel);
-      gtk_box_pack_start (GTK_BOX (filesel->button_area), 
-			  filesel->fileop_del_file, TRUE, TRUE, 0);
+			(gpointer) filesel);
+      gtk_box_pack_end (GTK_BOX (filesel->button_area), 
+			filesel->fileop_del_file, FALSE, FALSE, 0);
       gtk_widget_show (filesel->fileop_del_file);
     }
-
+  
   if (!filesel->fileop_ren_file)
     {
-      filesel->fileop_ren_file = gtk_button_new_with_mnemonic (_("_Rename File"));
+      filesel->fileop_ren_file = gtk_button_new ();
+      gtk_container_set_border_width (GTK_CONTAINER (filesel->fileop_ren_file), 4);
+      
+      bbox = gtk_hbox_new (FALSE, 2);
+      gtk_container_add (GTK_CONTAINER (filesel->fileop_ren_file), bbox);
+      
+      label = gtk_image_new_from_stock (GTK_STOCK_SAVE_AS,
+ 					GTK_ICON_SIZE_BUTTON);
+      gtk_box_pack_start (GTK_BOX (bbox), label, FALSE, FALSE, 0);
+      gtk_widget_show (label);
+      
+      label = gtk_label_new (_("_Rename File"));
+      gtk_label_set_use_underline (GTK_LABEL (label), TRUE);
+      gtk_label_set_mnemonic_widget (GTK_LABEL (label), filesel->fileop_ren_file);
+      gtk_box_pack_start (GTK_BOX (bbox), label, FALSE, FALSE, 0);
+      gtk_widget_show (label);
+      
+      gtk_widget_show (bbox);
+      
       g_signal_connect (filesel->fileop_ren_file, "clicked",
 			G_CALLBACK (gtk_file_selection_rename_file),
-			filesel);
-      gtk_box_pack_start (GTK_BOX (filesel->button_area), 
-			  filesel->fileop_ren_file, TRUE, TRUE, 0);
+			(gpointer) filesel);
+      gtk_box_pack_end (GTK_BOX (filesel->button_area), 
+			filesel->fileop_ren_file, FALSE, FALSE, 0);
       gtk_widget_show (filesel->fileop_ren_file);
     }
   
@@ -1752,6 +1902,100 @@
     gtk_widget_set_sensitive (fs->fileop_ren_file, sensitive);
 }
 
+static void
+home_clicked (GtkWidget *widget, gpointer data)
+{
+  char *dir;
+  
+  dir = g_strdup_printf ("%s/", g_get_home_dir());
+  
+  gtk_file_selection_populate (GTK_FILE_SELECTION (data), 
+			       dir, FALSE, FALSE);
+  g_free (dir);
+
+  gtk_widget_grab_focus (GTK_FILE_SELECTION (data)->selection_entry);
+}
+
+static char *
+get_desktop_directory (void)
+{
+  char *filename;
+  struct stat buf;
+
+  filename = g_build_filename (g_get_home_dir (), "Desktop", NULL);
+  if (lstat (filename, &buf) == 0) 
+    {
+      if (S_ISLNK (buf.st_mode)) 
+	{
+	  char link_target[MAXPATHLEN + 1];
+	  int len;
+
+	  len = readlink (filename, link_target, MAXPATHLEN);
+	  if (len > 0) 
+	    {
+	      char *desktop_filename;
+	      /* Add a trailing / if there isn't already one */
+	      link_target[len] = '\0';
+	      if (link_target[len - 1] == G_DIR_SEPARATOR) 
+		{
+		  link_target[len - 1] = '\0';
+		}
+
+	      if (!strcmp (link_target, ".gnome-desktop")) 
+		{
+		  g_free (filename);
+		  return g_build_filename (g_get_home_dir (), "Desktop", G_DIR_SEPARATOR_S, NULL);
+		}
+	      
+	      desktop_filename = g_build_filename (g_get_home_dir (), ".gnome-desktop", NULL);
+	      if (!strcmp (link_target, desktop_filename)) 
+		{
+		  g_free (desktop_filename);
+		  g_free (filename);
+		  return g_build_filename (g_get_home_dir (), "Desktop", G_DIR_SEPARATOR_S, NULL);
+		}
+	      g_free (desktop_filename);
+	    }
+	}
+      else if (S_ISDIR (buf.st_mode))
+	{
+	  g_free (filename);
+	  return g_build_filename (g_get_home_dir (), "Desktop", G_DIR_SEPARATOR_S, NULL);
+	}
+    }
+  g_free (filename);
+
+  return g_build_filename (g_get_home_dir (), ".gnome-desktop", G_DIR_SEPARATOR_S, NULL);
+}
+
+
+static void
+desktop_clicked (GtkWidget *widget, gpointer data)
+{
+  char *dir;
+  
+  dir = get_desktop_directory ();
+  gtk_file_selection_populate (GTK_FILE_SELECTION (data), 
+			       dir, FALSE, FALSE);
+  g_free (dir);
+
+  gtk_widget_grab_focus (GTK_FILE_SELECTION (data)->selection_entry);
+}
+
+static void 
+documents_clicked (GtkWidget *widget, gpointer data)
+{
+  char *dir;
+  dir = g_strdup_printf ("%s/Documents/", g_get_home_dir ());
+  
+  gtk_file_selection_populate (GTK_FILE_SELECTION (data),
+			       dir, FALSE, FALSE);
+  
+  g_free (dir);
+
+  gtk_widget_grab_focus (GTK_FILE_SELECTION (data)->selection_entry);
+}
+
 static gint
 gtk_file_selection_key_press (GtkWidget   *widget,
 			      GdkEventKey *event,
--- /dev/null
+++ gtk+-2.24.33/gtk/stock-icons/sun-icons.h
@@ -0,0 +1,823 @@
+/* GdkPixbuf RGBA C-Source image dump 1-byte-run-length-encoded */
+
+static const guint8 stock_desktop_48[] = 
+{ ""
+  /* Pixbuf magic (0x47646b50) */
+  "GdkP"
+  /* length: header (24) + pixel_data (6692) */
+  "\0\0\32<"
+  /* pixdata_type (0x2010002) */
+  "\2\1\0\2"
+  /* rowstride (276) */
+  "\0\0\1\24"
+  /* width (69) */
+  "\0\0\0E"
+  /* height (45) */
+  "\0\0\0-"
+  /* pixel_data: */
+  "\377\0\0\0\0\332\0\0\0\0\204\0\0\0\1\252\0\0\0\0\204\0\0\0\1\221\0\0"
+  "\0\0\3\0\0\0\2\0\0\0\5\0\0\0\10\202\0\0\0\11\3\0\0\0\10\0\0\0\5\0\0\0"
+  "\3\245\0\0\0\1\4\0\0\0\2\0\0\0\3\0\0\0\6\0\0\0\10\202\0\0\0\11\3\0\0"
+  "\0\10\0\0\0\5\0\0\0\2\216\0\0\0\0\2\0\0\0\2\0\0\0_\204\0\0\0\377\4\0"
+  "\0\0m\0\0\0\26\0\0\0\17\0\0\0\13\244\0\0\0\12\2\0\0\0\14\0\0\0\202\204"
+  "\0\0\0\377\4\0\0\0l\0\0\0\23\0\0\0\10\0\0\0\2\215\0\0\0\0\3\0\0\0\5\0"
+  "\0\0\377\266\276\312\377\202\245\257\276\377\1s}\214\377\252\0\0\0\377"
+  "\1\266\276\312\377\202\220\234\257\377\5s}\214\377\0\0\0\377\0\0\0)\0"
+  "\0\0\23\0\0\0\5\214\0\0\0\0\11\0\0\0\1\0\0\0\10\0\0\0\377\220\234\257"
+  "\377Ug\204\377DRj\377MNA\377\310\311\274\377\333\334\314\377\231\323"
+  "\324\300\377\4\322\323\300\377\321\323\277\377\321\323\276\377\321\322"
+  "\276\377\203\320\321\275\377\4\317\320\274\377\316\320\274\377\315\320"
+  "\273\377\315\317\272\377\202\315\316\271\377\13\315\315\271\377\314\315"
+  "\271\377qr^\377\245\257\276\377Ug\204\377DRj\377\0\0\0\377\0\0\0<\0\0"
+  "\0\35\0\0\0\10\0\0\0\1\213\0\0\0\0\7\0\0\0\1\0\0\0\11\0\0\0\377\220\234"
+  "\257\377DRj\377abR\377\227\230\177\377\231\274\276\237\377\32\273\275"
+  "\236\377\273\275\235\377\272\274\235\377\271\273\234\377\270\273\233"
+  "\377\270\272\232\377\267\271\231\377\266\270\231\377\265\270\230\377"
+  "\265\267\227\377\264\266\226\377\263\266\225\377\263\265\225\377\262"
+  "\264\224\377\261\264\223\377\260\263\222\377\260\262\221\377\257\262"
+  "\221\377or\\\377\220\234\257\377DRj\377\0\0\0\377\0\0\0E\0\0\0\"\0\0"
+  "\0\12\0\0\0\1\213\0\0\0\0\6\0\0\0\1\0\0\0\12\0\0\0\377s}\214\377abR\377"
+  "\227\230\177\377\231\274\276\237\377\33\273\275\236\377\272\274\235\377"
+  "\271\274\234\377\271\273\233\377\270\272\233\377\267\271\232\377\267"
+  "\271\231\377\266\270\230\377\265\267\227\377\264\267\227\377\264\266"
+  "\226\377\263\265\225\377\262\265\224\377\261\264\223\377\261\263\223"
+  "\377\260\263\222\377\257\262\221\377\257\261\220\377\256\260\217\377"
+  "\255\260\217\377np[\377\220\234\257\377\0\0\0\377\0\0\0F\0\0\0#\0\0\0"
+  "\12\0\0\0\1\213\0\0\0\0\5\0\0\0\1\0\0\0\10\0\0\0m\0\0\0\377\273\274\254"
+  "\377\230\274\276\237\377\35\273\275\236\377\272\275\235\377\272\274\235"
+  "\377\271\273\234\377\270\272\233\377\270\272\232\377\267\271\231\377"
+  "\266\270\231\377\265\270\230\377\265\267\227\377\264\266\226\377\263"
+  "\266\225\377\262\265\225\377\262\264\224\377\261\264\223\377\260\263"
+  "\222\377\260\262\221\377\257\261\221\377\256\261\220\377\255\260\217"
+  "\377\255\257\216\377\254\257\215\377\226\231|\377\0\0\0\377\0\0\0\253"
+  "\0\0\0A\0\0\0\37\0\0\0\11\0\0\0\1\214\0\0\0\0\4\0\0\0\6\0\0\0\26\0\0"
+  "\0\377\323\324\300\377\227\274\276\237\377\36\273\275\236\377\272\274"
+  "\235\377\271\273\234\377\271\273\233\377\270\272\233\377\267\271\232"
+  "\377\266\271\231\377\266\270\230\377\265\267\227\377\264\267\227\377"
+  "\264\266\226\377\263\265\225\377\262\265\224\377\261\264\223\377\261"
+  "\263\223\377\260\262\222\377\257\262\221\377\256\261\220\377\256\260"
+  "\217\377\255\260\217\377\254\257\216\377\254\256\215\377\253\256\214"
+  "\377\226\230z\377\0\0\0\377\0\0\0V\0\0\0""6\0\0\0\27\0\0\0\6\0\0\0\1"
+  "\214\0\0\0\0\4\0\0\0\3\0\0\0\17\0\0\0\377\323\324\300\377\211\274\276"
+  "\237\377\1z{g\377\214\0\0\0\377\36[\\L\377\267\271\232\377\271\273\234"
+  "\377\270\272\233\377\267\272\232\377\267\271\231\377\266\270\230\377"
+  "\265\270\230\377\265\267\227\377\264\266\226\377\263\266\225\377\262"
+  "\265\224\377\262\264\224\377\261\263\223\377\260\263\222\377\257\262"
+  "\221\377\257\261\220\377\256\261\220\377\255\260\217\377\255\257\216"
+  "\377\254\257\215\377\253\256\214\377\252\255\214\377\252\255\213\377"
+  "\225\227y\377\0\0\0\377\0\0\0O\0\0\0,\0\0\0\20\0\0\0\3\215\0\0\0\0\4"
+  "\0\0\0\2\0\0\0\14\0\0\0\377\323\324\300\377\211\274\276\237\377\3\0\0"
+  "\0\377\323\323\323\377\366\366\366\377\210\377\377\377\377\40\371\371"
+  "\371\377\332\332\332\377XXX\377,-%\377\263\265\226\377\266\270\231\377"
+  "\266\271\231\377\266\270\230\377\265\267\227\377\264\267\226\377\263"
+  "\266\226\377\263\265\225\377\262\264\224\377\261\264\223\377\261\263"
+  "\222\377\260\262\222\377\257\262\221\377\256\261\220\377\256\260\217"
+  "\377\255\260\216\377\254\257\216\377\253\256\215\377\253\256\214\377"
+  "\252\255\213\377\251\254\212\377\251\253\212\377\224\226x\377\0\0\0\377"
+  "\0\0\0K\0\0\0&\0\0\0\14\0\0\0\2\215\0\0\0\0\4\0\0\0\1\0\0\0\12\0\0\0"
+  "\377\323\324\300\377\211\274\276\237\377\2\0\0\0\377\366\366\366\377"
+  "\212\377\377\377\377\5\307\307\307\377\321\321\321\377\326\326\326\377"
+  "\0\0\0\377\260\262\223\377\202\264\267\227\377\30\264\266\226\377\263"
+  "\265\225\377\262\265\224\377\262\264\224\377\261\263\223\377\260\263"
+  "\222\377\257\262\221\377\257\261\220\377\256\261\220\377\255\260\217"
+  "\377\254\257\216\377\254\257\215\377\253\256\214\377\252\255\214\377"
+  "\252\254\213\377\251\254\212\377\250\253\211\377\247\252\210\377\223"
+  "\226x\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0\13\0\0\0\2\215\0\0\0\0\4\0\0"
+  "\0\1\0\0\0\12\0\0\0\377\323\324\300\377\211\274\276\237\377\1\0\0\0\377"
+  "\207\377\377\377\377#\376\376\376\377\377\377\377\377\376\376\376\377"
+  "\375\375\375\377\300\300\300\377\341\341\341\377\360\360\360\377\233"
+  "\233\233\377\0\0\0\377\255\257\220\377\262\265\225\377\263\265\225\377"
+  "\262\264\224\377\261\264\223\377\260\263\222\377\260\262\222\377\257"
+  "\262\221\377\256\261\220\377\256\260\217\377\255\260\216\377\254\257"
+  "\216\377\253\256\215\377\253\255\214\377\252\255\213\377\251\254\212"
+  "\377\250\253\212\377\250\253\211\377\247\252\210\377\246\251\207\377"
+  "\222\225v\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0\13\0\0\0\2\215\0\0\0\0\4"
+  "\0\0\0\1\0\0\0\12\0\0\0\377\323\324\300\377\211\274\276\237\377\1\0\0"
+  "\0\377\205\377\377\377\377%\376\376\376\377\375\375\375\377\374\374\373"
+  "\377\375\375\375\377\374\374\373\377\373\373\373\377\257\257\256\377"
+  "\351\351\351\377\377\377\377\377\337\337\337\377\217\217\217\377\0\0"
+  "\0\377\253\256\216\377\260\263\222\377\261\263\223\377\260\263\222\377"
+  "\257\262\221\377\257\261\220\377\256\261\217\377\255\260\217\377\254"
+  "\257\216\377\254\256\215\377\253\256\214\377\252\255\213\377\251\254"
+  "\213\377\251\254\212\377\250\253\211\377\247\252\210\377\247\252\207"
+  "\377\246\251\207\377\245\250\206\377\220\224u\377\0\0\0\377\0\0\0I\0"
+  "\0\0%\0\0\0\13\0\0\0\2\215\0\0\0\0\4\0\0\0\1\0\0\0\12\0\0\0\377\323\324"
+  "\300\377\211\274\276\237\377\1\0\0\0\377\203\377\377\377\377\32\376\376"
+  "\376\377\375\375\375\377\374\374\373\377\373\373\373\377\372\372\371"
+  "\377\373\373\373\377\372\372\371\377\371\371\370\377\244\244\243\377"
+  "\360\360\360\377\377\377\377\377\364\364\364\377\317\317\317\377\242"
+  "\242\242\37744+\377\252\255\215\377\257\261\220\377\257\262\221\377\256"
+  "\261\220\377\255\260\217\377\255\257\216\377\254\257\215\377\253\256"
+  "\215\377\253\255\214\377\252\255\213\377\251\254\212\377\202\250\253"
+  "\211\377\13\247\252\210\377\246\251\207\377\245\251\206\377\245\250\205"
+  "\377\244\247\205\377\220\222t\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0\13\0"
+  "\0\0\2\215\0\0\0\0\4\0\0\0\1\0\0\0\12\0\0\0\377\323\324\300\377\211\274"
+  "\276\237\377\15\0\0\0\377\377\377\377\377\376\376\376\377\375\375\375"
+  "\377\374\374\373\377\373\373\373\377\372\372\371\377\371\371\370\377"
+  "\370\370\367\377\371\371\370\377\370\370\367\377\370\367\366\377\236"
+  "\236\236\377\206\0\0\0\377\30VWG\377\252\255\215\377\256\260\217\377"
+  "\255\260\217\377oq\\\377\15\15\13\3779.'\377\214\214p\377\245\247\207"
+  "\377\251\254\212\377\250\253\211\377\247\252\210\377\246\252\207\377"
+  "\246\251\207\377\245\250\206\377\244\247\205\377\244\247\204\377\243"
+  "\246\203\377\217\221s\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0\13\0\0\0\2\215"
+  "\0\0\0\0\4\0\0\0\1\0\0\0\12\0\0\0\377\323\324\300\377\211\274\276\237"
+  "\377+\0\0\0\377\377\377\377\377\374\374\373\377\373\373\373\377\372\372"
+  "\371\377\371\371\370\377\370\370\367\377\370\367\366\377\367\366\365"
+  "\377\370\367\366\377\367\366\365\377\366\366\364\377\364\363\362\377"
+  "\336\335\334\377\323\322\320\377\267\267\265\377\237\236\235\377poo\377"
+  "ebZ\377\0\0\0\377\242\244\206\377op[\377\24\24\21\377E\77\77\377\347"
+  "\254\243\377\302[K\377,\30\23\377\201\204i\377\250\253\211\377\247\252"
+  "\210\377\246\251\207\377\245\250\206\377\245\250\205\377\244\247\205"
+  "\377\243\246\204\377\242\246\203\377\242\245\202\377\216\220q\377\0\0"
+  "\0\377\0\0\0I\0\0\0%\0\0\0\13\0\0\0\2\215\0\0\0\0\4\0\0\0\1\0\0\0\12"
+  "\0\0\0\377\323\324\300\377\210\274\276\237\377,\273\275\236\377\0\0\0"
+  "\377\377\377\377\377\372\372\371\377\371\371\370\377\370\370\367\377"
+  "\370\367\366\377\367\366\365\377\366\366\364\377\365\364\363\377\366"
+  "\366\364\377\365\364\363\377\364\363\362\377\362\362\360\377\344\344"
+  "\342\377\332\331\327\377\330\330\326\377\315\314\312\377\257\256\254"
+  "\377\210\204{\377\0\0\0\377\21\21\14\377D@5\377\350\332\260\377\240\231"
+  "\223\377\235NB\377n#\26\377\40\17\12\377or[\377\246\251\207\377\246\251"
+  "\206\377\245\250\206\377\244\247\205\377\243\247\204\377\243\246\203"
+  "\377\242\245\202\377\241\245\202\377\241\244\201\377\215\220p\377\0\0"
+  "\0\377\0\0\0I\0\0\0%\0\0\0\13\0\0\0\2\215\0\0\0\0\4\0\0\0\1\0\0\0\12"
+  "\0\0\0\377\323\324\300\377\207\274\276\237\377-\273\275\236\377\272\274"
+  "\235\377\0\0\0\377\377\377\377\377\370\370\367\377\370\367\366\377\367"
+  "\366\365\377\366\366\364\377\365\364\363\377\364\363\362\377\363\363"
+  "\361\377\364\363\362\377\363\363\361\377\362\362\360\377\357\357\355"
+  "\377\356\355\353\377\355\354\352\377\351\350\346\377\325\324\323\377"
+  "\275\274\273\377\21\17\15\377,*#\377\360\337\253\377\320\264f\377\272"
+  "\214,\377x_2\3774\30\23\377\31\26\22\377\202\205j\377\242\245\203\377"
+  "\245\250\206\377\245\250\205\377\244\247\204\377\243\246\204\377\242"
+  "\246\203\377\242\245\202\377\241\244\201\377\240\244\200\377\237\243"
+  "\200\377\214\217p\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0\13\0\0\0\2\215\0"
+  "\0\0\0\4\0\0\0\1\0\0\0\12\0\0\0\377\323\324\300\377\205\274\276\237\377"
+  "\202\273\275\236\377\6\272\274\235\377\271\273\234\377\0\0\0\377\377"
+  "\377\377\377\366\365\364\377\365\365\363\377\202\364\363\362\377%\363"
+  "\363\361\377\362\362\360\377\361\361\357\377\362\362\360\377\361\361"
+  "\357\377\361\360\356\377\356\355\353\377\354\353\351\377\352\351\347"
+  "\377\332\326\315\377\26\25\21\377-,&\377\362\342\262\377\320\264e\377"
+  "\270\211+\377\244q\24\377O4\6\377\33\27\15\377su]\377\234\237\177\377"
+  "\244\247\204\377\243\246\204\377\244\247\205\377\243\247\204\377\243"
+  "\246\203\377\242\245\202\377\241\245\202\377\240\244\201\377\240\243"
+  "\200\377\237\242\177\377\236\242~\377\213\216o\377\0\0\0\377\0\0\0I\0"
+  "\0\0%\0\0\0\13\0\0\0\2\215\0\0\0\0\4\0\0\0\1\0\0\0\12\0\0\0\377\323\324"
+  "\300\377\204\274\276\237\3770\273\275\236\377\272\274\235\377\272\274"
+  "\234\377\271\273\234\377\270\272\233\377\0\0\0\377\377\377\377\377\364"
+  "\363\362\377\363\362\361\377\362\362\360\377\360\360\356\377\357\357"
+  "\355\377\361\360\356\377\360\357\355\377\361\360\356\377\360\357\355"
+  "\377\357\356\354\377\354\353\351\377\305\303\274\377\25\24\16\377-,&"
+  "\377\362\343\263\377\320\265g\377\271\215/\377\247r\26\377Z=\11\377\33"
+  "\25\7\377[]J\377\233\236~\377\242\245\203\377\243\246\204\377\242\246"
+  "\203\377\244\247\204\377\243\246\204\377\242\246\203\377\242\245\202"
+  "\377\241\244\201\377\240\243\200\377\237\243\200\377\237\242\177\377"
+  "\236\241~\377\235\241}\377\211\215m\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0"
+  "\13\0\0\0\2\215\0\0\0\0\4\0\0\0\1\0\0\0\12\0\0\0\377\323\324\300\377"
+  "\202\274\276\237\3772\273\275\236\377\273\275\235\377\272\274\235\377"
+  "\271\273\234\377\270\273\233\377\270\272\232\377\267\271\231\377\0\0"
+  "\0\377\377\377\377\377\364\363\362\377\363\362\361\377\362\362\360\377"
+  "\360\360\356\377\357\357\355\377\361\360\356\377\360\357\355\377\361"
+  "\360\356\377\360\357\355\377\351\350\346\377<8/\377+(\36\377\360\337"
+  "\247\377\320\264h\377\276\2202\377\260|\33\377`A\13\377\30\20\1\377="
+  ">1\377\225\230z\377\242\245\203\377\243\247\204\377\243\246\203\377\244"
+  "\247\205\377\243\247\204\377\243\246\203\377\242\245\202\377\241\244"
+  "\201\377\240\244\201\377\240\243\200\377\237\242\177\377\236\242~\377"
+  "\235\241}\377\235\240}\377\234\240|\377\210\214l\377\0\0\0\377\0\0\0"
+  "I\0\0\0%\0\0\0\13\0\0\0\2\215\0\0\0\0\20\0\0\0\1\0\0\0\12\0\0\0\377\323"
+  "\324\300\377\274\276\237\377\273\275\236\377\272\274\235\377\271\274"
+  "\234\377\271\273\233\377\270\272\233\377\267\271\232\377\267\271\231"
+  "\377\266\270\230\377\0\0\0\377\377\377\377\377\360\360\356\377\202\357"
+  "\357\355\377\2\357\356\354\377\356\355\353\377\203\355\354\352\377!\347"
+  "\346\344\377NJB\377\256\247\240\377\315\265\221\377\305\236@\377\267"
+  "\202\36\377bD\16\377\36\27\7\377:84\377\0\0\0\377\214\216q\377\244\247"
+  "\205\377\243\246\204\377\242\246\203\377\244\247\204\377\243\246\203"
+  "\377\242\245\203\377\241\245\202\377\241\244\201\377\240\243\200\377"
+  "\237\243\177\377\237\242\177\377\236\241~\377\235\241}\377\234\240|\377"
+  "\234\237{\377\233\237{\377\207\213k\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0"
+  "\13\0\0\0\2\215\0\0\0\0\21\0\0\0\1\0\0\0\12\0\0\0\377\322\323\300\377"
+  "\272\275\235\377\272\274\235\377\271\273\234\377\270\272\233\377\270"
+  "\272\232\377\267\271\231\377\266\270\231\377\265\270\230\377\265\267"
+  "\227\377\0\0\0\377\377\377\377\377\355\355\353\377\355\354\352\377\203"
+  "\354\353\351\377$\353\352\350\377\351\350\345\377\353\352\350\377\37"
+  "\37\37\377&$\40\377\220~i\377\232zU\377{`3\377\26\20\7\377DDC\377\270"
+  "\267\264\377\233\225\212\377\0\0\0\377\216\220s\377\243\246\203\377\244"
+  "\247\205\377\243\246\204\377\242\246\203\377\242\245\202\377\241\244"
+  "\201\377\240\244\201\377\240\243\200\377\237\242\177\377\236\242~\377"
+  "\235\241}\377\235\240}\377\234\240|\377\233\237{\377\232\236z\377\232"
+  "\235y\377\207\212j\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0\13\0\0\0\2\215\0"
+  "\0\0\0\20\0\0\0\1\0\0\0\12\0\0\0\377\321\323\277\377\271\273\234\377"
+  "\271\273\233\377\270\272\233\377\267\271\232\377\266\271\231\377\266"
+  "\270\230\377\265\267\227\377\264\267\227\377\264\266\226\377\0\0\0\377"
+  "\377\377\377\377\353\352\350\377\202\351\350\346\377\1\350\347\345\377"
+  "\202\350\347\344\377\2\347\346\343\377\36\35\35\377\202\24\24\24\377"
+  "\37\26\26\23\377\"!\37\377LLJ\377\261\260\255\377\322\321\315\377\331"
+  "\330\324\377\237\231\216\377\0\0\0\377\217\222t\377\244\247\204\377\243"
+  "\246\203\377\242\245\203\377\241\245\202\377\241\244\201\377\240\243"
+  "\200\377\237\243\177\377\236\242\177\377\236\241~\377\235\241}\377\234"
+  "\240|\377\234\237{\377\233\236{\377\232\236z\377\231\235y\377\231\234"
+  "x\377\206\211i\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0\13\0\0\0\2\215\0\0\0"
+  "\0\20\0\0\0\1\0\0\0\12\0\0\0\377\321\322\276\377\270\272\233\377\267"
+  "\272\232\377\267\271\231\377\266\270\230\377\265\270\230\377\265\267"
+  "\227\377\264\266\226\377\263\266\225\377\262\265\224\377\0\0\0\377\377"
+  "\377\377\377\347\346\343\377\203\346\345\342\377%\345\344\341\377\346"
+  "\344\341\377\345\344\340\377\340\336\333\377\320\317\313\377\302\302"
+  "\276\377\303\303\277\377\320\317\313\377\330\327\323\377\331\330\324"
+  "\377\330\326\322\377\331\327\323\377\237\231\215\377\0\0\0\377\216\221"
+  "s\377\242\246\203\377\242\245\202\377\241\244\201\377\240\244\200\377"
+  "\237\243\200\377\237\242\177\377\236\242~\377\235\241}\377\235\240|\377"
+  "\234\237|\377\233\237{\377\232\236z\377\232\235y\377\231\235x\377\230"
+  "\234x\377\227\233w\377\205\210h\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0\13"
+  "\0\0\0\2\215\0\0\0\0\30\0\0\0\1\0\0\0\12\0\0\0\377\320\321\275\377\267"
+  "\271\232\377\266\271\231\377\266\270\230\377\265\267\227\377\264\267"
+  "\226\377\263\266\226\377\263\265\225\377\262\264\224\377\261\264\223"
+  "\377\0\0\0\377\371\371\371\377\344\343\340\377\343\342\337\377\343\342"
+  "\336\377\344\342\337\377\344\343\337\377\342\341\335\377\343\342\336"
+  "\377\342\341\335\377\340\337\333\377\203\333\332\326\377\35\332\330\324"
+  "\377\334\332\326\377\331\327\323\377\330\326\322\377\236\230\215\377"
+  "\0\0\0\377\215\220q\377\241\245\202\377\241\244\201\377\240\243\200\377"
+  "\237\242\177\377\236\242~\377\236\241~\377\235\240}\377\234\240|\377"
+  "\233\237{\377\233\236z\377\232\236z\377\231\235y\377\231\234x\377\230"
+  "\234w\377\227\233v\377\226\232v\377\204\207g\377\0\0\0\377\0\0\0I\0\0"
+  "\0%\0\0\0\13\0\0\0\2\215\0\0\0\0""8\0\0\0\1\0\0\0\12\0\0\0\377\320\321"
+  "\275\377\266\270\230\377\265\270\230\377\264\267\227\377\264\266\226"
+  "\377\263\265\225\377\262\265\224\377\262\264\224\377\261\263\223\377"
+  "\260\263\222\377\0\0\0\377\355\355\355\377\341\340\335\377\341\337\334"
+  "\377\341\340\334\377\340\337\333\377\342\341\335\377\340\337\333\377"
+  "\341\340\334\377\340\337\333\377\341\340\334\377\337\336\332\377\340"
+  "\336\332\377\335\333\327\377\334\332\326\377\331\327\323\377\330\326"
+  "\321\377\327\325\321\377\235\227\213\377\0\0\0\377\214\217p\377\240\243"
+  "\200\377\237\243\200\377\237\242\177\377\236\241~\377\235\241}\377\234"
+  "\240|\377\234\237|\377\233\237{\377\232\236z\377\232\235y\377\231\235"
+  "x\377\230\234x\377\227\233w\377\227\233v\377\226\232u\377\225\231t\377"
+  "\202\206f\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0\13\0\0\0\2\215\0\0\0\0\30"
+  "\0\0\0\1\0\0\0\12\0\0\0\377\317\320\274\377\265\267\227\377\264\266\226"
+  "\377\263\266\226\377\263\265\225\377\262\264\224\377\261\264\223\377"
+  "\260\263\222\377\260\262\222\377\257\262\221\377\0\0\0\377\321\321\321"
+  "\377\341\337\333\377\340\336\332\377\337\336\332\377\336\335\331\377"
+  "\340\337\333\377\336\335\331\377\340\336\332\377\336\335\331\377\340"
+  "\336\332\377\202\336\334\330\377\202\334\332\326\377\34\330\326\322\377"
+  "\327\326\321\377\325\323\316\377\233\225\212\377\0\0\0\377\213\216o\377"
+  "\237\242\177\377\236\242~\377\236\241~\377\235\240}\377\234\240|\377"
+  "\233\237{\377\233\236z\377\232\236z\377\231\235y\377\230\234x\377\230"
+  "\234w\377\227\233v\377\226\232v\377\226\231u\377\225\231t\377\224\230"
+  "s\377\202\205e\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0\13\0\0\0\2\215\0\0\0"
+  "\0\32\0\0\0\1\0\0\0\12\0\0\0\377\315\320\273\377\264\266\226\377\263"
+  "\265\225\377\262\265\224\377\261\264\223\377\261\263\223\377\260\263"
+  "\222\377\257\262\221\377\257\261\220\377\256\261\217\377\0\0\0\377\231"
+  "\230\221\377\243\236\222\377\244\236\223\377\243\235\222\377\243\235"
+  "\221\377\243\235\222\377\241\234\220\377\242\234\220\377\241\234\220"
+  "\377\242\234\220\377\241\233\217\377\241\233\220\377\202\237\231\215"
+  "\377\202\235\227\214\377\21\233\226\212\377gcY\377\0\0\0\377\213\215"
+  "o\377\236\241~\377\235\241}\377\234\240|\377\234\237{\377\233\237{\377"
+  "\232\236z\377\231\235y\377\231\235x\377\230\234w\377\227\233w\377\227"
+  "\232v\377\226\232u\377\225\231t\377\202\224\230s\377\7\224\227s\377\202"
+  "\205e\377\0\0\0\377\0\0\0I\0\0\0%\0\0\0\13\0\0\0\2\215\0\0\0\0\16\0\0"
+  "\0\2\0\0\0\14\0\0\0\377\315\317\271\377\263\265\225\377\262\264\224\377"
+  "\261\264\223\377\260\263\222\377\260\262\221\377\257\262\221\377\256"
+  "\261\220\377\255\260\217\377\255\257\216\377moY\377\222\0\0\0\377\17"
+  "WZF\377\216\221q\377\235\240}\377\234\240|\377\233\237{\377\233\236z"
+  "\377\232\235y\377\231\235y\377\230\234x\377\230\233w\377\227\233v\377"
+  "\226\232u\377\225\231u\377\225\231t\377\224\230s\377\203\224\227s\377"
+  "\6\202\205e\377\0\0\0\377\0\0\0K\0\0\0&\0\0\0\14\0\0\0\2\215\0\0\0\0"
+  "\34\0\0\0\3\0\0\0\202\0\0\0\377\326\327\306\377\261\264\223\377\261\263"
+  "\223\377\260\263\222\377\257\262\221\377\256\261\220\377\256\260\217"
+  "\377\255\260\217\377\254\257\216\377\254\256\215\377\251\254\212\377"
+  "\240\242\202\377\225\230{\377\224\227y\377\222\225w\377\222\224v\377"
+  "\221\224v\377\221\223v\377\220\222u\377\217\222t\377\217\222s\377\216"
+  "\221r\377\215\220r\377\214\220q\377\214\217p\377\202\213\216o\377\16"
+  "\212\215o\377\212\214n\377\216\221q\377\227\232x\377\234\237{\377\233"
+  "\236{\377\232\236z\377\231\235y\377\231\234x\377\230\234w\377\227\233"
+  "w\377\226\232v\377\226\232u\377\225\231t\377\202\224\230s\377\204\224"
+  "\227s\377\6\202\205e\377\0\0\0\377\0\0\0\243\0\0\0,\0\0\0\20\0\0\0\3"
+  "\215\0\0\0\0\17\0\0\0\6\0\0\0\377v\204\234\377rr^\377\260\263\222\377"
+  "\260\262\221\377\257\261\221\377\256\261\220\377\255\260\217\377\255"
+  "\257\216\377\254\257\215\377\253\256\215\377\252\255\214\377\252\255"
+  "\213\377\251\254\212\377\202\250\253\211\377\33\247\252\210\377\246\251"
+  "\207\377\245\250\206\377\245\250\205\377\244\247\205\377\243\246\204"
+  "\377\242\246\203\377\242\245\202\377\241\244\201\377\240\244\201\377"
+  "\240\243\200\377\237\242\177\377\236\242~\377\235\241}\377\235\240}\377"
+  "\234\237|\377\233\237{\377\232\236z\377\232\235y\377\231\235y\377\230"
+  "\234x\377\230\233w\377\227\233v\377\226\232u\377\225\231u\377\225\231"
+  "t\377\224\230s\377\206\224\227s\377\7z}_\377\222\230\242\377\0\0\0\377"
+  "\0\0\0""6\0\0\0\27\0\0\0\6\0\0\0\1\213\0\0\0\0\15\0\0\0\1\0\0\0\10\0"
+  "\0\0\377Ug\204\377v\204\234\377pr]\377\256\261\220\377\256\260\217\377"
+  "\255\260\216\377\254\257\216\377\253\256\215\377\253\256\214\377\252"
+  "\255\213\377\202\251\254\212\377\34\250\253\211\377\247\252\210\377\246"
+  "\251\207\377\246\251\206\377\245\250\206\377\244\247\205\377\243\247"
+  "\204\377\243\246\203\377\242\245\202\377\241\245\202\377\241\244\201"
+  "\377\240\243\200\377\237\243\177\377\236\242~\377\236\241~\377\235\240"
+  "}\377\234\240|\377\233\237{\377\233\236z\377\232\236z\377\231\235y\377"
+  "\231\234x\377\230\234w\377\227\233v\377\226\232v\377\226\232u\377\225"
+  "\231t\377\224\230s\377\210\224\227s\377\7\266\276\312\377DRj\377\0\0"
+  "\0\377\0\0\0A\0\0\0\37\0\0\0\11\0\0\0\1\213\0\0\0\0\3\0\0\0\1\0\0\0\12"
+  "\0\0\0\377\202Ug\204\377\11v\204\234\377\213\215r\377\217\220u\377\227"
+  "\232|\377\226\231{\377\226\230{\377\226\230z\377\225\227y\377\224\226"
+  "x\377\202\223\226x\377\32\222\225w\377\221\224v\377\221\224u\377\220"
+  "\223t\377\220\222t\377\217\222s\377\217\221r\377\216\220q\377\215\220"
+  "p\377\214\220p\377\214\217p\377\213\216o\377\212\216n\377\212\215m\377"
+  "\211\214m\377\210\214l\377\207\213k\377\207\212j\377\207\212i\377\206"
+  "\211i\377\205\210i\377\205\210h\377\204\207g\377\203\207f\377\203\206"
+  "f\377\202\206e\377\210\202\205e\377\10\245\257\276\377Ug\204\377DRj\377"
+  "\0\0\0\377\0\0\0G\0\0\0#\0\0\0\12\0\0\0\1\213\0\0\0\0\3\0\0\0\1\0\0\0"
+  "\12\0\0\0\377\2036AU\377\1KUd\377\252\0\0\0\377\1\204\214\230\377\202"
+  "6AU\377\6+4D\377\0\0\0\377\0\0\0F\0\0\0#\0\0\0\12\0\0\0\1\213\0\0\0\0"
+  "\3\0\0\0\1\0\0\0\10\0\0\0\211\204\0\0\0\377\4\0\0\0\253\0\0\0V\0\0\0"
+  "O\0\0\0K\244\0\0\0I\2\0\0\0K\0\0\0\243\204\0\0\0\377\5\0\0\0\247\0\0"
+  "\0=\0\0\0\36\0\0\0\10\0\0\0\1\214\0\0\0\0\12\0\0\0\5\0\0\0\23\0\0\0*"
+  "\0\0\0=\0\0\0F\0\0\0G\0\0\0A\0\0\0""6\0\0\0,\0\0\0&\244\0\0\0%\13\0\0"
+  "\0&\0\0\0,\0\0\0""6\0\0\0A\0\0\0G\0\0\0F\0\0\0=\0\0\0*\0\0\0\24\0\0\0"
+  "\5\0\0\0\1\214\0\0\0\0\4\0\0\0\2\0\0\0\11\0\0\0\23\0\0\0\36\202\0\0\0"
+  "#\4\0\0\0\37\0\0\0\27\0\0\0\20\0\0\0\14\244\0\0\0\13\4\0\0\0\14\0\0\0"
+  "\20\0\0\0\27\0\0\0\37\202\0\0\0#\4\0\0\0\36\0\0\0\24\0\0\0\11\0\0\0\2"
+  "\216\0\0\0\0\3\0\0\0\2\0\0\0\5\0\0\0\10\202\0\0\0\12\3\0\0\0\11\0\0\0"
+  "\6\0\0\0\3\246\0\0\0\2\3\0\0\0\3\0\0\0\6\0\0\0\11\202\0\0\0\12\3\0\0"
+  "\0\10\0\0\0\6\0\0\0\2\221\0\0\0\0\205\0\0\0\1\251\0\0\0\0\205\0\0\0\1"
+  "\315\0\0\0\0"};
+
+
+/* GdkPixbuf RGBA C-Source image dump 1-byte-run-length-encoded */
+
+static const guint8 stock_home_48[] = 
+{ ""
+  /* Pixbuf magic (0x47646b50) */
+  "GdkP"
+  /* length: header (24) + pixel_data (6912) */
+  "\0\0\33\30"
+  /* pixdata_type (0x2010002) */
+  "\2\1\0\2"
+  /* rowstride (192) */
+  "\0\0\0\300"
+  /* width (48) */
+  "\0\0\0""0"
+  /* height (48) */
+  "\0\0\0""0"
+  /* pixel_data: */
+  "\223\377\377\377\0\1\0\0\0\1\202\377\377\377\0\13\0\0\0\31\0\0\0C\35"
+  "\36\35Etvt\224\322\331\321\333\204\212\204\315\17\17\17""9\7\7\7\10\377"
+  "\377\377\0\0\0\0\1\377\377\377\0\202\0\0\0\1\6\0\0\0+\6\7\6.svs6\242"
+  "\246\242\242\33\34\33_\0\0\0\2\230\377\377\377\0\1\0\0\0\1\202\377\377"
+  "\377\0\25\0\0\0\7\0\0\0.\11\11\11IXYXW\275\277\274\255\347\355\347\352"
+  "\331\344\330\371\205\217\204\353\26\26\26O\11\11\11\7\377\377\377\0\0"
+  "\0\0\2\377\377\377\0\0\0\0\13\0\0\0*''&%\240\242\237E\364\370\363\263"
+  "\237\244\237\343\4\4\4W\0\0\0\1\204\377\377\377\0\1\0\0\0\1\225\377\377"
+  "\377\0\25\0\0\0\34\0\0\0""3787K\241\244\241o\345\353\346\302\332\342"
+  "\332\365\263\277\261\376\261\300\261\376\204\217\203\357#$#X\11\11\11"
+  "\6\377\377\377\0\0\0\0\3\0\0\0\31\12\12\12!]^]$\321\324\320~\347\355"
+  "\346\335\316\330\314\372qvq\350\0\0\0E\227\377\377\377\0\31\0\0\0\1\377"
+  "\377\377\0\0\0\0\16\0\0\0%\33\34\33<\201\203\202t\330\333\327\300\343"
+  "\354\342\342\277\313\276\371\250\266\247\376\245\264\244\377\264\303"
+  "\264\376\215\231\214\364%'%o\11\11\11\4\36\36\36\27\0\0\0#\36\37\37\34"
+  "\224\226\2242\351\356\351\230\327\337\327\350\263\277\262\375\270\305"
+  "\267\377]a]\340\0\0\0*\203\377\377\377\0\1\0\0\0\7\225\377\377\377\0"
+  "\27\0\0\0&(*'q\257\265\257\274\350\356\347\351\320\332\317\373\257\274"
+  "\255\377\246\264\245\377\251\267\250\377\247\265\246\377\263\301\262"
+  "\376\224\240\223\372(+(\222YYY\17\5\6\5""6KLK%\311\313\311X\357\364\356"
+  "\276\303\315\302\361\247\265\246\375\253\273\252\377\263\277\262\376"
+  "BEB\316\0\0\0\24\231\377\377\377\0\27\0\0\0$\77D>}\302\317\300\331\272"
+  "\307\271\373\247\265\246\377\250\266\247\377\252\270\251\377\251\267"
+  "\250\377\244\261\243\377\253\272\252\377\231\243\230\3749::\321\30\30"
+  "\30t}\177}\250\347\353\347\267\340\350\340\343\262\276\261\373\245\263"
+  "\244\377\247\265\246\377\261\277\260\376\251\263\250\371.1.\253\2\2\2"
+  "\11\205\377\377\377\0\1\0\0\0\1\223\377\377\377\0\21\0\0\0-,0,e\246\265"
+  "\245\313\257\276\256\373\250\266\247\377\251\267\250\377\250\266\247"
+  "\377\243\261\242\377\240\255\237\377\224\234\223\377-,,\377ABA\377\266"
+  "\271\266\377\357\364\356\377\313\325\312\377\250\266\247\377\246\264"
+  "\244\377\202\250\267\247\377\4\264\302\262\377\232\243\231\372\36\37"
+  "\36\244\4\4\4\21\225\377\377\377\0\1\0\0\0\1\202\377\377\377\0\21\0\0"
+  "\0\30\0\0\0dFJF\210\264\301\263\335\256\275\255\373\251\266\250\377\246"
+  "\264\245\377\242\257\241\377\244\261\243\377nrn\377;<;\377\215\216\216"
+  "\377\340\343\340\377\345\354\344\377\272\306\271\377\245\264\244\377"
+  "\247\265\246\377\203\251\267\250\377\4\266\304\265\377\213\222\213\372"
+  "\23\23\23\275121\11\223\377\377\377\0\1\0\0\0\1\202\377\377\377\0\22"
+  "\0\0\0\10\0\0\0(\12\12\12tOPO\324\261\270\260\357\271\306\270\370\247"
+  "\265\246\375\244\261\243\377\243\257\242\377\237\250\236\377LLL\377c"
+  "cc\377\303\304\302\377\361\364\361\377\327\337\327\377\260\273\257\377"
+  "\245\264\244\377\250\266\247\377\204\251\267\250\377\4\267\305\266\377"
+  "pwp\367,,,\266\352\357\352\1\221\377\377\377\0\202\0\0\0\1\202\377\377"
+  "\377\0\21\0\0\0\36\0\0\0\77///\202\221\224\221\330\327\335\326\365\303"
+  "\316\302\377\246\263\245\377\241\257\240\377\246\262\245\377\205\211"
+  "\203\377DDD\377\220\221\220\377\346\350\346\377\353\360\352\377\303\316"
+  "\302\377\253\270\252\377\247\265\246\377\205\251\267\250\377\4\252\270"
+  "\251\377\267\304\266\377[`[\365IKI\240\205\377\377\377\0\1\0\0\0\2\213"
+  "\377\377\377\0\1\0\0\0\1\202\377\377\377\0\22\0\0\0\21\0\0\0""3\24\24"
+  "\24_kmk\264\305\311\304\352\330\342\327\374\265\301\264\377\242\257\242"
+  "\377\242\257\241\377\247\261\247\377]^]\377aba\377\276\277\275\377\363"
+  "\366\361\377\326\336\325\377\262\276\261\377\247\265\246\377\250\266"
+  "\247\377\206\251\267\250\377\4\253\272\252\377\261\276\260\377FIF\365"
+  ";\77:u\205\377\377\377\0\3\0\0\0\6\377\377\377\0\0\0\0\2\207\377\377"
+  "\377\0\2\0\0\0\1\0\0\0\2\202\377\377\377\0\21\0\0\0(\0\0\0;IJH|\257\263"
+  "\256\322\334\344\333\370\303\317\303\377\250\265\246\377\242\256\241"
+  "\377\250\263\247\377\227\235\226\377LLL\377\204\206\204\377\337\341\337"
+  "\377\355\362\354\377\302\314\301\377\252\267\250\377\247\266\246\377"
+  "\210\251\267\250\377\4\254\273\253\377\251\264\250\377474\367LRKN\205"
+  "\377\377\377\0\3\0\0\0\6\377\377\377\0\0\0\0\1\206\377\377\377\0\1\0"
+  "\0\0\1\202\377\377\377\0\22\0\0\0\30\0\0\0\77\37\40\37>\210\213\210\227"
+  "\324\331\323\350\325\337\324\373\263\300\262\377\243\260\242\377\244"
+  "\261\243\377\250\263\250\377nrn\377XXX\377\257\260\257\377\360\364\360"
+  "\377\333\341\332\377\261\276\260\377\246\265\245\377\250\266\247\377"
+  "\210\251\267\250\377\5\250\266\247\377\260\276\257\377\227\241\226\377"
+  "')'\357z\204y6\207\377\377\377\0\1\0\0\0\1\204\377\377\377\0\202\0\0"
+  "\0\1\24\377\377\377\0\1\1\1\5\0\0\0""5\4\5\4-Z]ZP\300\306\300\261\332"
+  "\344\332\353\277\313\276\375\247\264\246\377\243\261\242\377\246\261"
+  "\245\377\236\246\235\377EFE\377rsr\377\323\326\323\377\357\365\357\377"
+  "\305\317\305\377\250\265\247\377\246\265\245\377\250\266\247\377\211"
+  "\251\267\250\377\5\250\266\247\377\263\301\262\377\212\223\211\377*-"
+  "*\336\205\220\204\22\215\377\377\377\0\23\0\0\0\1\0\0\0\"\1\1\1<-.-F"
+  "\230\235\230\177\331\340\330\331\311\324\310\372\255\272\254\377\244"
+  "\262\243\377\244\261\243\377\250\263\247\377}\201|\377CCC\377\230\231"
+  "\227\377\352\356\352\377\342\351\342\377\265\301\264\377\246\264\245"
+  "\377\250\266\247\377\213\251\267\250\377\5\250\266\247\377\264\302\263"
+  "\377rxr\377.2.\330[bZ\6\211\377\377\377\0\1\0\0\0\1\202\377\377\377\0"
+  "\23\0\0\0\23\0\0\0+\23\25\23""3psph\315\323\314\303\325\336\324\363\265"
+  "\302\265\376\246\264\245\377\244\262\243\377\247\263\246\377\243\255"
+  "\242\377UWU\377aca\377\302\306\302\377\356\363\356\377\316\326\315\377"
+  "\252\267\252\377\246\264\245\377\250\266\247\377\214\251\267\250\377"
+  "\5\250\266\247\377\265\303\264\377gmg\377\27\31\27\327ai`\5\206\377\377"
+  "\377\0\1\0\0\0\1\203\377\377\377\0\23\0\0\0\7\0\0\0(\7\7\6/ABAN\255\261"
+  "\254\247\337\346\336\343\302\315\301\374\253\270\253\377\245\264\244"
+  "\377\244\261\243\377\251\264\250\377\221\227\220\377IJJ\377\222\224\222"
+  "\377\342\346\340\377\344\353\344\377\272\305\272\377\245\262\244\377"
+  "\245\263\244\377\203\247\265\246\377\2\250\266\247\377\251\266\250\377"
+  "\212\251\267\250\377\4\264\302\263\377glg\374\17\20\17\312\202\215\201"
+  "\7\206\377\377\377\0\1\0\0\0\2\202\377\377\377\0\25\0\0\0\21\0\0\0""2"
+  "$%$R\211\214\210\206\331\337\330\321\325\336\324\367\261\275\260\377"
+  "\245\263\244\377\244\262\243\377\240\256\237\377\245\260\245\377fjg\377"
+  "cec\377\276\301\275\377\353\357\352\377\320\330\317\377\254\267\253\377"
+  "\241\257\240\377\244\262\243\377\245\263\244\377\246\263\245\377\202"
+  "\246\264\245\377\202\247\265\246\377\203\250\266\247\377\207\251\267"
+  "\250\377\4\264\302\263\377glg\366\14\15\14\274\221\235\220\11\206\377"
+  "\377\377\0\1\0\0\0\2\202\377\377\377\0\22\5\5\5JKNJ\251\277\306\300\323"
+  "\341\351\341\362\276\311\276\376\244\263\244\377\243\261\242\377\242"
+  "\257\240\377\232\247\230\377\216\226\215\377;=;\377{~z\377\327\332\326"
+  "\377\342\346\341\377\272\304\271\377\242\257\241\377\241\256\240\377"
+  "\243\261\242\377\202\244\261\243\377\6\244\262\243\377\245\262\244\377"
+  "\245\263\244\377\246\263\245\377\246\264\245\377\247\264\246\377\202"
+  "\247\265\246\377\1\250\265\247\377\202\250\266\247\377\204\251\267\250"
+  "\377\4\264\302\263\377glg\364\12\13\12\252\213\226\212\6\202\377\377"
+  "\377\0\1\212\223\211\1\203\377\377\377\0\1\0\0\0\1\202\377\377\377\0"
+  "\22\20\21\20\206\217\230\216\355\314\327\314\374\252\265\251\377\241"
+  "\256\240\377\242\260\241\377\241\257\241\377\231\246\230\377\214\230"
+  "\214\377#\"#\377INI\377\304\316\303\377\300\312\300\377\250\264\250\377"
+  "\237\254\236\377\240\256\237\377\242\257\241\377\242\260\241\377\203"
+  "\243\260\242\377\2\244\261\243\377\244\262\243\377\202\245\263\244\377"
+  "\1\246\263\245\377\202\246\264\245\377\202\247\264\246\377\1\250\266"
+  "\247\377\204\251\267\250\377\4\264\302\263\377glg\362\11\11\11\240IO"
+  "H\5\202\0\0\0\2\2LPL\3\0\0\0\3\205\377\377\377\0\16\6\6\6lQXQ\340\223"
+  "\240\222\375\237\253\236\377\242\257\240\377\240\254\236\377\230\245"
+  "\227\377\215\231\214\377rzr\377\17\20\17\377MTM\377\235\252\234\377\235"
+  "\253\234\377\236\254\235\377\202\240\255\237\377\2\241\256\240\377\241"
+  "\257\240\377\203\242\257\241\377\2\243\260\242\377\243\261\242\377\202"
+  "\244\261\243\377\202\245\262\244\377\4\245\263\244\377\246\263\245\377"
+  "\247\264\246\377\250\266\247\377\202\251\267\250\377\202\252\267\251"
+  "\377\12\264\302\263\377glg\354\13\13\13\227'+'\12""222\11\37\37\37\7"
+  "\17\20\17\6\0\0\0\5\0\0\0\2\0\0\0\1\203\377\377\377\0\14\0\0\0""4'+'"
+  "\314~\211}\374\235\252\234\377\237\254\236\377\233\247\232\377\216\232"
+  "\215\377\177\212\177\377^f]\377\17\17\17\377W^W\377\231\245\230\377\202"
+  "\236\253\235\377\202\237\254\236\377\202\240\255\237\377\1\240\256\237"
+  "\377\202\241\256\240\377\2\241\257\240\377\242\257\241\377\202\243\260"
+  "\242\377\6\243\261\242\377\244\261\243\377\245\262\244\377\0\0\0\377"
+  "\3\4\3\377\252\267\246\377\202\251\267\250\377\15\252\270\251\377\251"
+  "\267\250\377\264\302\263\377glg\356\10\11\10\230\"$\"\32\12\12\12\26"
+  "\0\0\0\22\0\0\0\16\0\0\0\11\0\0\0\6\0\0\0\3\0\0\0\1\202\377\377\377\0"
+  "\16\0\0\0\10\22\23\22\243dmc\371\226\243\225\376\234\252\233\377\227"
+  "\244\226\377\210\223\207\377u\177u\377QWP\377\15\16\16\377ckc\377\233"
+  "\250\232\377\235\252\234\377\235\251\233\377\202\236\253\235\377\203"
+  "\237\254\236\377\202\240\255\237\377\2\240\256\237\377\241\256\240\377"
+  "\202\242\257\241\377\6\242\260\241\377\244\261\243\377)$(\377\357\336"
+  "\253\377VC\7\377'#\25\377\203\251\267\250\377\15\252\270\251\377\264"
+  "\302\263\377fkf\363\12\13\12\250\12\13\12""3\4\4\4/\36\36\36-\0\0\0\37"
+  "\0\0\0\26\0\0\0\15\0\0\0\7\0\0\0\4\0\0\0\1\202\377\377\377\0\15\2\3\2"
+  "HDJC\350\211\224\207\376\231\246\230\377\225\242\225\377\207\223\206"
+  "\377s~s\377JOJ\377\15\16\15\377ltk\377\233\250\232\377\234\251\233\377"
+  "\233\250\233\377\202\234\251\233\377\203\235\252\234\377\202\236\253"
+  "\235\377\13\236\254\235\377A@A\377\0\0\0\377\242\257\241\377\242\260"
+  "\241\377)$)\377\364\343\271\377\336\304v\377\335\304v\377YF\22\377H9"
+  "\14\377\203\251\267\250\377\32\264\302\263\377[`[\374\31\33\31\276\5"
+  "\6\5[\3\3\3U%%%S\0\0\0:\0\0\0(\0\0\0\31\0\0\0\17\0\0\0\10\0\0\0\3\0\0"
+  "\0\1\377\377\377\0\0\0\0\13&*&\301w\200v\375\224\240\224\377\225\241"
+  "\224\377\210\223\207\377w\201w\377OSO\377\24\26\24\377x\201v\377\232"
+  "\244\231\377\234\250\233\377\202\233\247\232\377\2\233\250\232\377\233"
+  "\251\233\377\202\234\251\233\377\203\235\252\234\377\13""9<9\377\0\0"
+  "\0\377\242\257\241\377)$'\377\365\343\265\377\345\312w\377\307\254Y\377"
+  "\311\256Y\377\304\254a\377VB\6\377\32\26\5\377\202\251\267\250\377\36"
+  "\257\274\256\377;>;\377.2.\323\3\3\3\212\0\0\0\200\0\0\0o\0\0\0[\0\0"
+  "\0C\0\0\0,\0\0\0\32\0\0\0\15\0\0\0\5\0\0\0\2\377\377\377\0\0\0\0\1\17"
+  "\21\17v\\d\\\370\213\227\213\376\223\237\222\377\211\224\210\377y\203"
+  "x\377TYT\377\31\33\30\377qxo\377\230\245\230\377\233\247\230\377\233"
+  "\246\231\377\232\245\232\377\232\247\231\377\232\247\232\377\202\233"
+  "\250\232\377\35\234\250\233\377\234\251\233\377\235\252\234\377A@A\377"
+  "\0\0\0\377)$)\377\360\342\304\377\335\304y\377\177g!\377\204j\31\377"
+  "~e\26\377yi=\377\230\202A\377t_'\377$\37\15\377\253\272\252\377\250\263"
+  "\247\377$&$\377@E\77\343\2\2\2\252\0\0\0\233\1\1\1\211\0\0\0t\0\0\0\\"
+  "\0\0\0@\0\0\0'\0\0\0\24\0\0\0\11\0\0\0\3\202\377\377\377\0\24\1\2\1/"
+  ">D>\336~\210}\374\221\234\220\377\213\226\212\377}\206|\377Z`Y\377\40"
+  "#\37\377`g`\377\230\245\230\377\231\247\230\377\231\246\231\377\232\245"
+  "\231\377\231\246\231\377\231\246\230\377\232\246\231\377\232\247\231"
+  "\377\233\250\232\377\234\251\233\377\235\252\234\377\202A<A\377\30\355"
+  "\342\320\377\340\311\211\377OD\35\377[K\26\377\\I\17\377aK\10\377\\I"
+  "\17\377XE\27\377\213s'\377PC\31\377\36\34\22\377\227\241\226\377\21\22"
+  "\21\377272\341\1\1\1\271\0\0\0\254\0\0\0\236\0\0\0\216\0\0\0x\0\0\0Y"
+  "\0\0\0:\0\0\0\40\0\0\0\16\0\0\0\6\202\377\377\377\0\3\0\0\0\7#%\"\225"
+  "lul\363\202\214\230\213\377)\200\213\177\377\\b[\377-2-\377EKE\377\225"
+  "\243\224\377\230\244\227\377\231\245\227\377\230\244\230\377\230\245"
+  "\230\377\230\245\227\377\231\245\230\377\232\247\231\377\233\250\232"
+  "\377\234\251\233\377\235\252\234\377101\377\354\342\322\377\336\304r"
+  "\377YE\16\377ULJ\377\265\256\251\377\354\337\316\377\354\336\266\377"
+  "\277\257\214\377OH;\377^I\13\377{g/\377WF\32\377\"\37\20\377\11\11\11"
+  "\377\25\27\25\327\0\0\0\302\0\0\0\272\0\0\0\265\0\0\0\253\0\0\0\227\0"
+  "\0\0w\0\0\0Q\0\0\0.\0\0\0\27\0\0\0\12\202\377\377\377\0%\0\0\0\1\12\13"
+  "\11""0RXQ\323\204\217\203\377\214\230\213\377\202\215\201\377]c]\377"
+  ":\77:\377>C>\377\224\240\223\377\230\244\226\377\227\244\227\377\227"
+  "\245\227\377\227\244\226\377\230\245\227\377\231\246\230\377\232\247"
+  "\231\377\233\250\232\377\234\251\233\3771,0\377\366\343\264\377\340\304"
+  "n\377XB\2\377TL-\377\255\256\252\377\346\336\346\377\377\372\377\377"
+  "\377\377\377\377\336\336\336\377\264\256\263\377RH0\377WI\40\377k]-\377"
+  "UC\14\377\27\23\4\377\10\11\10\325\0\0\0\314\202\0\0\0\315\7\0\0\0\307"
+  "\0\0\0\265\0\0\0\223\0\0\0i\0\0\0@\0\0\0\"\0\0\0\17\203\377\377\377\0"
+  "\12\0\0\0\6""6;5\232x\201w\374\213\227\212\377\204\217\203\377aha\377"
+  "GMF\377>C=\377\215\232\214\377\226\243\226\377\202\227\244\226\377!\230"
+  "\243\226\377\230\245\227\377\232\246\230\377\232\247\231\377\233\250"
+  "\232\377)((\377\364\342\266\377\315\261Z\377\\F\3\377WL@\377\264\262"
+  "\263\377\346\342\346\377\377\372\377\377\377\377\377\377\377\372\377"
+  "\377\377\377\377\377\346\342\346\377\275\262\264\377QH5\377VI#\377rb"
+  ".\377[G\12\377\26\22\3\374\0\0\0\334\0\0\0\341\0\0\0\342\0\0\0\336\0"
+  "\0\0\314\0\0\0\255\0\0\0\201\0\0\0U\0\0\0""0\0\0\0\30\204\377\377\377"
+  "\0\10\32\34\32afof\365\206\222\206\377\205\220\205\377iqh\377W]U\377"
+  ":@:\377\212\224\211\377\202\227\243\226\377\14\227\244\225\377\231\244"
+  "\226\377\231\245\227\377\232\245\230\377\232\247\231\377+$\"\377\361"
+  "\337\245\377\261\226B\377TC\14\377KLG\377\254\245\244\377\346\342\346"
+  "\377\206\377\372\377\377\20\356\352\356\377\254\241\244\377QH4\377YI"
+  "\32\377v]\16\377UD\16\377\25\20\4\375\2\2\1\360\0\0\0\362\0\0\0\355\0"
+  "\0\0\336\0\0\0\302\0\0\0\232\0\0\0l\0\0\0A\0\0\0\"\204\377\377\377\0"
+  "\10\5\6\5""2QXQ\341\201\212\200\376\205\220\205\377qzp\377aja\377161"
+  "\377\210\223\210\377\202\227\243\226\377\13\230\243\226\377\227\244\226"
+  "\377\230\245\227\377\231\245\230\377)$(\377\333\304~\377\276\243Q\377"
+  "WE\30\377RLP\377\244\241\244\377\336\326\336\377\210\377\372\377\377"
+  "\17\336\332\336\377\264\256\263\377SH,\377YI\32\377zb\27\377\\G\10\377"
+  "\21\16\2\376\0\0\0\371\0\0\0\365\0\0\0\352\0\0\0\323\0\0\0\257\0\0\0"
+  "\202\0\0\0T\0\0\0/\204\377\377\377\0,\0\0\0\15""373\266v\177v\375\204"
+  "\220\204\377z\205z\377ktj\377-2-\377aja\377\226\240\225\377\227\243\225"
+  "\377\227\242\225\377\230\243\226\377\231\245\227\377\231\246\230\377"
+  "\232\247\231\377%#\25\377.(\30\377\40\30\27\377{}{\377\325\326\325\377"
+  "\346\342\346\377\377\372\377\377\377\362\366\377f\202\315\377(i\353\377"
+  "\23=\236\377.%I\377\377\372\377\377\377\362\366\377\356\352\356\377\275"
+  "\276\275\377jij\377101\377-%\26\377!\32\2\377\0\0\0\375\0\0\0\374\0\0"
+  "\0\370\0\0\0\357\0\0\0\334\0\0\0\276\0\0\0\224\0\0\0e\0\0\0<\204\377"
+  "\377\377\0!\0\0\0\1\23\25\23s`i`\362\177\213~\377~\212}\377s}s\3775:"
+  "4\377[bZ\377\220\235\216\377\226\243\225\377\227\243\226\377\230\244"
+  "\230\377\230\245\230\377\231\245\230\377\232\247\231\377\233\250\232"
+  "\377\234\251\233\377\30\30\30\377\203\201\203\377\325\326\325\377\356"
+  "\346\356\377\377\372\377\377Eg\302\377w\244\375\377\330\345\377\377\250"
+  "\304\376\377*p\365\377\22,s\377\377\377\377\377\366\362\366\377\325\316"
+  "\325\377{y{\377\0\0\0\377\202\0\0\0\376\11\0\0\0\375\0\0\0\373\0\0\0"
+  "\366\0\0\0\354\0\0\0\333\0\0\0\301\0\0\0\233\0\0\0n\0\0\0D\205\377\377"
+  "\377\0\10\2\2\2/ELD\334w\200w\377\200\213\177\377z\204z\377<C=\377V["
+  "V\377\216\230\216\377\202\227\243\226\377\3\227\245\227\377\230\245\227"
+  "\377\231\245\230\377\202\232\247\231\377\34\233\250\232\377\40\40\40"
+  "\377\213\215\213\377\336\326\336\377\356\352\356\377\377\372\377\377"
+  "=x\363\377\336\351\377\377\276\324\377\377u\243\376\377g\227\372\377"
+  "\2""9\246\377\375\373\377\377\366\362\366\377\315\312\315\377{}{\377"
+  "\0\0\0\377\0\0\0\376\0\0\0\375\0\0\0\372\0\0\0\365\0\0\0\354\0\0\0\337"
+  "\0\0\0\314\0\0\0\264\0\0\0\223\0\0\0k\0\0\0C\205\377\377\377\0\10\0\0"
+  "\0\13&*&\256iri\372|\206{\377~\210}\377OWO\377IMH\377\203\217\203\377"
+  "\202\227\243\226\377\2\227\244\227\377\230\245\227\377\202\231\245\230"
+  "\377\35\231\246\230\377\232\246\231\377\30\30\30\377\224\225\224\377"
+  "\325\326\325\377\366\356\366\377\377\372\377\3776a\317\377\313\334\377"
+  "\377\240\300\377\377c\230\376\3773v\373\377\3=\260\377\376\373\377\377"
+  "\356\352\356\377\336\326\336\377\224\221\224\377\0\0\0\377\0\0\0\375"
+  "\0\0\0\372\0\0\0\364\0\0\0\351\0\0\0\331\0\0\0\305\0\0\0\256\0\0\0\225"
+  "\0\0\0x\0\0\0W\0\0\0""7\205\377\377\377\0\10\0\0\0\1\12\13\12SSZR\346"
+  "qzp\376\200\211\177\377ZbZ\377\77D>\377\177\210~\377\202\227\243\226"
+  "\377!\227\244\226\377\231\244\227\377\230\245\227\377\230\244\227\377"
+  "\230\245\227\377\231\245\230\377\30\30\30\377\224\221\224\377\325\326"
+  "\325\377\356\352\356\377\377\372\377\377*Z\315\377\270\320\377\377}\251"
+  "\376\377F\205\376\377*n\363\377\5A\271\377\377\372\377\377\366\352\356"
+  "\377\325\322\325\377\224\221\224\377\0\0\0\377\0\0\0\372\0\0\0\364\0"
+  "\0\0\347\0\0\0\324\0\0\0\273\0\0\0\237\0\0\0\203\0\0\0j\0\0\0S\0\0\0"
+  ";\0\0\0%\206\377\377\377\0*\0\0\0\16""251\254]f]\364}\207|\377nwn\377"
+  "040\377nvm\377\226\243\225\377\227\243\225\377\227\243\226\377\226\244"
+  "\226\377\226\243\225\377\227\243\226\377\227\244\226\377\231\245\227"
+  "\377\30\30\30\377\234\225\234\377\325\326\325\377\356\356\356\377\377"
+  "\372\377\377*]\323\377\247\304\377\377h\233\376\377A\200\373\377-l\353"
+  "\377\20>\250\377\377\372\377\377\356\352\356\377\336\326\336\377\224"
+  "\221\224\377\0\0\0\377\0\0\0\364\0\0\0\350\0\0\0\324\0\0\0\270\0\0\0"
+  "\227\0\0\0v\0\0\0Y\0\0\0B\0\0\0""1\0\0\0!\0\0\0\25\206\377\377\377\0"
+  "*\0\0\0\1\23\23\23YBGB\350u~t\377z\203y\377:\77""9\377_h_\377\227\242"
+  "\225\377\226\237\224\377\226\242\224\377\225\241\225\377\225\242\224"
+  "\377\226\242\225\377\226\243\225\377\221\235\220\377\30\30\30\377\224"
+  "\221\224\377\336\326\336\377\356\352\356\377\377\372\377\377!\\\327\377"
+  "\230\273\376\377a\226\376\377C\177\367\377$c\342\377\7@\264\377\366\366"
+  "\366\377\366\352\356\377\325\322\325\377\224\221\224\377\0\0\0\377\0"
+  "\0\0\351\0\0\0\326\0\0\0\272\0\0\0\227\0\0\0q\0\0\0P\0\0\0""6\0\0\0$"
+  "\0\0\0\30\0\0\0\20\0\0\0\11\207\377\377\377\0\12\10\10\10\")+)\312go"
+  "f\374\200\211\177\377HMF\377;@:\377\220\233\217\377\225\236\222\377\224"
+  "\237\221\377\223\236\221\377\202\224\240\223\377\35\214\230\214\377\204"
+  "\217\203\377\30\30\30\377\224\225\224\377\325\326\325\377\366\356\366"
+  "\377\377\372\377\377\17F\275\377z\247\377\377K\204\365\3777x\372\377"
+  "\33b\351\377\4@\265\377\377\372\377\377\356\352\356\377\336\326\336\377"
+  "\224\221\224\377\0\0\0\377\0\0\0\326\0\0\0\274\0\0\0\231\0\0\0r\0\0\0"
+  "N\0\0\0""1\0\0\0\35\0\0\0\21\0\0\0\12\0\0\0\6\0\0\0\3\207\377\377\377"
+  "\0)\3\3\3\6\37!\37\177SYR\365v\200v\377LRL\3779>8\377\205\220\204\377"
+  "\223\236\221\377\222\232\217\377\223\235\220\377\221\234\220\377\207"
+  "\222\206\377\200\212\200\377oxn\377\30\30\30\377\224\221\224\377\325"
+  "\326\325\377\356\352\356\377\377\372\377\377\32C\254\377F\205\377\377"
+  "9t\357\377.u\374\377\23Z\340\377\2=\262\377\377\372\377\377\366\352\356"
+  "\377\325\322\325\377\224\221\224\377\0\0\0\377\0\0\0\271\0\0\0\232\0"
+  "\0\0u\0\0\0P\0\0\0""1\0\0\0\34\0\0\0\16\0\0\0\7\0\0\0\3\0\0\0\2\0\0\0"
+  "\1\207\377\377\377\0'\4\4\4\1\10\11\10""7:@:\337jsj\377S[R\377GNF\377"
+  "u}s\377\220\233\217\377\216\232\213\377\214\230\212\377\202\215\200\377"
+  "y\203x\377^e^\377\77D@\377\30\30\30\377\203\201\203\377\275\272\275\377"
+  "\325\316\325\377\336\332\336\377\17<\246\377\22Z\343\377\23W\334\377"
+  "\6K\320\377\13I\310\377\1""5\231\377\335\332\340\377\315\312\315\377"
+  "\275\272\275\377\203}\203\377\0\0\0\377\0\0\0\223\0\0\0s\0\0\0Q\0\0\0"
+  "3\0\0\0\34\0\0\0\16\0\0\0\6\0\0\0\2\0\0\0\1\212\377\377\377\0\16\1\1"
+  "\1\14\40\"\40\256`h`\375^e\\\3779\77""9\377_g_\377\220\231\216\377\210"
+  "\225\207\377~\210}\377s}s\377NSM\377<@;\377\25\26\25\376\1\1\1\363\216"
+  "\0\0\0\377\11A\10\0\377\0\0\0h\0\0\0M\0\0\0""2\0\0\0\35\0\0\0\17\0\0"
+  "\0\6\0\0\0\2\0\0\0\1\213\377\377\377\0\25\1\1\1\1\12\13\12WOVO\346fo"
+  "e\377BF@\377muk\377\212\226\211\377z\205{\377jsi\377AF@\3776:5\377\12"
+  "\12\11\375\1\1\1\353\0\0\0\277\0\0\0\242\0\0\0\221\0\0\0\202\0\0\0v\0"
+  "\0\0m\0\0\0g\0\0\0c\204\0\0\0a\13\0\0\0_\0\0\0\\\0\0\0W\0\0\0M\0\0\0"
+  "=\0\0\0+\0\0\0\33\0\0\0\17\0\0\0\7\0\0\0\3\0\0\0\1\215\377\377\377\0"
+  "\25\0\0\0\14""040\235gog\364dlc\377fof\377y\204v\377XaX\3778=8\377(,"
+  "(\376\2\2\2\365\0\0\0\325\0\0\0\251\0\0\0\214\0\0\0v\0\0\0a\0\0\0P\0"
+  "\0\0D\0\0\0<\0\0\0""8\0\0\0""6\0\0\0""5\203\0\0\0""4\12\0\0\0""3\0\0"
+  "\0""2\0\0\0.\0\0\0(\0\0\0\37\0\0\0\25\0\0\0\14\0\0\0\6\0\0\0\3\0\0\0"
+  "\1\216\377\377\377\0\23\0\0\0\2\12\13\12""6RYQ\327nxn\376PXP\377HNF\377"
+  "/3/\377\22\24\22\374\1\1\1\336\0\0\0\246\0\0\0\207\0\0\0v\0\0\0_\0\0"
+  "\0J\0\0\0""7\0\0\0(\0\0\0\40\0\0\0\34\0\0\0\31\206\0\0\0\27\10\0\0\0"
+  "\26\0\0\0\24\0\0\0\21\0\0\0\15\0\0\0\11\0\0\0\5\0\0\0\2\0\0\0\1\217\377"
+  "\377\377\0\22\0\0\0\1\0\0\0\10\24\27\24\231EKE\366\77E\77\377\34\37\34"
+  "\377\5\6\5\364\0\0\0\267\0\0\0j\0\0\0Z\0\0\0S\0\0\0G\0\0\0""6\0\0\0'"
+  "\0\0\0\33\0\0\0\21\0\0\0\14\0\0\0\12\206\0\0\0\10\203\0\0\0\7\3\0\0\0"
+  "\6\0\0\0\4\0\0\0\3\202\0\0\0\1\220\377\377\377\0\21\0\0\0\1\0\0\0\3\1"
+  "\1\1""6\5\6\5\307\4\4\4\337\0\0\0\276\0\0\0t\0\0\0;\0\0\0""2\0\0\0""0"
+  "\0\0\0,\0\0\0$\0\0\0\33\0\0\0\21\0\0\0\12\0\0\0\6\0\0\0\4\212\0\0\0\2"
+  "\203\0\0\0\1\211\377\377\377\0"};
+
+
+/* GdkPixbuf RGBA C-Source image dump 1-byte-run-length-encoded */
+
+static const guint8 stock_documents_48[] = 
+{ ""
+  /* Pixbuf magic (0x47646b50) */
+  "GdkP"
+  /* length: header (24) + pixel_data (3237) */
+  "\0\0\14\275"
+  /* pixdata_type (0x2010002) */
+  "\2\1\0\2"
+  /* rowstride (192) */
+  "\0\0\0\300"
+  /* width (48) */
+  "\0\0\0""0"
+  /* height (48) */
+  "\0\0\0""0"
+  /* pixel_data: */
+  "\377\0\0\0\0\377\0\0\0\0\363\0\0\0\0\1XXX\2\240\0\0\0\0\1\0\0\0Y\213"
+  "\0\0\0\377\7\0\0\0\366\0\0\0\362\16\16\16\377(((\377aaa\333\0\0\0\10"
+  "\0\0\0\1\235\0\0\0\0\3\0\0\0\377\323\323\323\377\366\366\366\377\210"
+  "\377\377\377\377\1\371\371\371\377\202\371\371\370\377\6\347\347\347"
+  "\377\344\344\344\377\315\315\315\377\37\37\37\344\0\0\0\24\0\0\0\2\234"
+  "\0\0\0\0\2\0\0\0\377\366\366\366\377\212\377\377\377\377\11\371\371\370"
+  "\377\357\357\356\377\257\257\256\377\351\351\351\377\377\377\377\377"
+  "\263\263\263\377888\375\0\0\0\16\0\0\0\2\233\0\0\0\0\1\0\0\0\377\202"
+  "\377\377\377\377\205yyy\377\2xxx\377yyy\377\202xxx\377\12\371\371\370"
+  "\377\356\356\356\377\244\244\243\377\360\360\360\377\377\377\377\377"
+  "\364\364\364\377\253\253\253\377\5\5\5\231\0\0\0\13\0\0\0\1\232\0\0\0"
+  "\0\1\0\0\0\377\205\377\377\377\377\11\376\376\376\377\375\375\375\377"
+  "\374\374\373\377\375\375\375\377\374\374\373\377\373\373\373\377\371"
+  "\371\370\377\362\362\362\377\236\236\236\377\204\0\0\0\377\3\0\0\0\330"
+  "\0\0\0\33\0\0\0\5\225\0\0\0\0\1\0\0\0Y\205\0\0\0\377\202\377\377\377"
+  "\377\1yyy\377\202xxx\377\202www\377\16vvv\377www\377vvv\377vvu\377\371"
+  "\371\370\377\364\364\364\377\324\324\323\377\271\267\266\377\203\203"
+  "\201\377\204\203\201\377jgc\377\0\0\0\343\0\0\0&\0\0\0\7\225\0\0\0\0"
+  "\3\0\0\0\377\323\323\323\377\366\366\366\377\202\377\377\377\377\26\0"
+  "\0\0\377\377\377\377\377\376\376\376\377\375\375\375\377\374\374\373"
+  "\377\373\373\373\377\372\372\371\377\371\371\370\377\370\370\367\377"
+  "\371\371\370\377\370\370\367\377\370\367\366\377\371\371\370\377\363"
+  "\362\361\377\340\340\337\377\334\332\330\377\312\312\310\377\266\266"
+  "\264\377rpl\377\0\0\0\356\0\0\0)\0\0\0\10\225\0\0\0\0\2\0\0\0\377\366"
+  "\366\366\377\203\377\377\377\377\16\0\0\0\377\377\377\377\377\374\374"
+  "\373\377www\377vvv\377vvu\377uuu\377uut\377utt\377uut\377utt\377tts\377"
+  "\364\363\362\377\361\360\357\377\202\360\357\355\377\6\345\344\342\377"
+  "\304\303\300\377\201}t\377\0\0\0\377\0\0\0,\0\0\0\11\225\0\0\0\0\1\0"
+  "\0\0\377\202\377\377\377\377\202yyy\377\13\0\0\0\377\377\377\377\377"
+  "\372\372\371\377\371\371\370\377\370\370\367\377\370\367\366\377\367"
+  "\366\365\377\366\366\364\377\365\364\363\377\366\366\364\377\365\364"
+  "\363\377\204\364\363\362\377\1\353\352\350\377\202\341\337\334\377\4"
+  "\213\206}\377\0\0\0\377\0\0\0.\0\0\0\11\220\0\0\0\0\1\0\0\0Y\205\0\0"
+  "\0\377\204\377\377\377\377\7\0\0\0\377\377\377\377\377\370\370\367\377"
+  "uut\377utt\377tts\377tss\377\204ssr\377\2rrq\377qqp\377\202ppo\377\7"
+  "llk\377jih\377\341\337\334\377\244\236\223\377\0\0\0\377\0\0\0/\0\0\0"
+  "\11\220\0\0\0\0\3\0\0\0\377\323\323\323\377\366\366\366\377\202\377\377"
+  "\377\377\1\0\0\0\377\202\377\377\377\377\6yyy\377xxx\377\0\0\0\377\377"
+  "\377\377\377\366\365\364\377\365\365\363\377\202\364\363\362\377\20\363"
+  "\363\361\377\362\362\360\377\361\361\357\377\362\362\360\377\361\361"
+  "\357\377\361\360\356\377\356\355\353\377\354\353\351\377\347\346\343"
+  "\377\342\341\337\377\344\343\340\377\341\337\334\377\244\236\223\377"
+  "\0\0\0\377\0\0\0/\0\0\0\11\220\0\0\0\0\2\0\0\0\377\366\366\366\377\203"
+  "\377\377\377\377\12\0\0\0\377\377\377\377\377\376\376\376\377\375\375"
+  "\375\377\374\374\373\377\0\0\0\377\377\377\377\377\364\363\362\377sr"
+  "r\377rrq\377\202qqp\377\17rqp\377qqp\377rqp\377qqp\377qpo\377oon\377"
+  "nml\377llj\377lkj\377kji\377\341\337\334\377\244\236\223\377\0\0\0\377"
+  "\0\0\0/\0\0\0\11\220\0\0\0\0\1\0\0\0\377\202\377\377\377\377\202yyy\377"
+  "\33\0\0\0\377\377\377\377\377\374\374\373\377www\377vvv\377\0\0\0\377"
+  "\377\377\377\377\364\363\362\377\363\362\361\377\362\362\360\377\360"
+  "\360\356\377\357\357\355\377\361\360\356\377\360\357\355\377\361\360"
+  "\356\377\360\357\355\377\357\356\354\377\354\353\351\377\350\347\345"
+  "\377\345\344\341\377\344\343\340\377\342\341\336\377\341\337\334\377"
+  "\244\236\223\377\0\0\0\377\0\0\0/\0\0\0\11\220\0\0\0\0\1\0\0\0\377\204"
+  "\377\377\377\377\10\0\0\0\377\377\377\377\377\372\372\371\377\371\371"
+  "\370\377\370\370\367\377\0\0\0\377\377\377\377\377\360\360\356\377\202"
+  "\230\250\265\377\4\230\250\264\377\230\247\264\377\227\247\263\377\355"
+  "\354\352\377\202poo\377\13oon\377nml\377mmk\377kki\377kjh\377jjh\377"
+  "\340\337\333\377\241\234\220\377\0\0\0\377\0\0\0/\0\0\0\11\220\0\0\0"
+  "\0\1\0\0\0\377\202\377\377\377\377\21yyy\377xxx\377\0\0\0\377\377\377"
+  "\377\377\370\370\367\377uut\377utt\377\0\0\0\377\377\377\377\377\355"
+  "\355\353\377\227\247\263\377\276\274\307\377\355\337\261\377\227\246"
+  "\263\377\226\246\262\377\351\350\345\377\353\352\350\377\202\351\350"
+  "\345\377\12\345\344\341\377\346\344\341\377\343\342\336\377\337\336\332"
+  "\377\336\335\331\377\335\334\330\377\241\233\220\377\0\0\0\377\0\0\0"
+  "/\0\0\0\11\220\0\0\0\0\17\0\0\0\377\377\377\377\377\376\376\376\377\375"
+  "\375\375\377\374\374\373\377\0\0\0\377\377\377\377\377\366\365\364\377"
+  "\365\365\363\377\364\363\362\377\0\0\0\377\377\377\377\377\353\352\350"
+  "\377\225\245\261\377\274\272\305\377\202\353\336\257\377\17\225\244\261"
+  "\377\347\346\343\377nml\377mmk\377mlk\377lki\377kki\377jig\377ihf\377"
+  "hhf\377\334\333\327\377\241\233\220\377\0\0\0\377\0\0\0/\0\0\0\11\220"
+  "\0\0\0\0\40\0\0\0\377\377\377\377\377\374\374\373\377www\377vvv\377\0"
+  "\0\0\377\377\377\377\377\364\363\362\377srr\377rrq\377\0\0\0\377\377"
+  "\377\377\377\347\346\343\377\224\243\260\377\273\271\304\377\352\335"
+  "\256\377\351\334\256\377\224\243\257\377\345\344\340\377\346\344\341"
+  "\377\345\344\340\377\344\343\337\377\342\341\335\377\340\337\333\377"
+  "\336\335\331\377\334\333\327\377\333\331\325\377\331\327\323\377\237"
+  "\231\215\377\0\0\0\377\0\0\0/\0\0\0\11\220\0\0\0\0\16\0\0\0\377\377\377"
+  "\377\377\372\372\371\377\371\371\370\377\370\370\367\377\0\0\0\377\377"
+  "\377\377\377\364\363\362\377\363\362\361\377\362\362\360\377\0\0\0\377"
+  "\371\371\371\377\344\343\340\377\223\242\256\377\202\272\267\302\377"
+  "\5\272\270\302\377\222\241\255\377\343\342\336\377kjh\377kki\377\202"
+  "jjh\377\11ihf\377hgf\377hge\377ffd\377\330\326\322\377\236\230\215\377"
+  "\0\0\0\377\0\0\0/\0\0\0\11\220\0\0\0\0\10\0\0\0\377\377\377\377\377\370"
+  "\370\367\377uut\377utt\377\0\0\0\377\377\377\377\377\360\360\356\377"
+  "\202qqp\377\26\0\0\0\377\355\355\355\377\341\340\335\377\341\337\334"
+  "\377\341\340\334\377\340\337\333\377\342\341\335\377\340\337\333\377"
+  "\341\340\334\377\340\337\333\377\341\340\334\377\337\336\332\377\340"
+  "\336\332\377\335\333\327\377\334\332\326\377\331\327\323\377\330\326"
+  "\321\377\327\325\321\377\235\227\213\377\0\0\0\377\0\0\0/\0\0\0\11\220"
+  "\0\0\0\0\25\0\0\0\377\377\377\377\377\366\365\364\377\365\365\363\377"
+  "\364\363\362\377\0\0\0\377\377\377\377\377\355\355\353\377\355\354\352"
+  "\377\354\353\351\377\0\0\0\377\321\321\321\377\341\337\333\377\340\336"
+  "\332\377\337\336\332\377\336\335\331\377\340\337\333\377\336\335\331"
+  "\377\340\336\332\377\336\335\331\377\340\336\332\377\202\336\334\330"
+  "\377\202\334\332\326\377\7\330\326\322\377\327\326\321\377\325\323\316"
+  "\377\233\225\212\377\0\0\0\377\0\0\0/\0\0\0\11\220\0\0\0\0\10\0\0\0\377"
+  "\377\377\377\377\364\363\362\377srr\377rrq\377\0\0\0\377\377\377\377"
+  "\377\353\352\350\377\202nnm\377\15\0\0\0\377\231\230\221\377\243\236"
+  "\222\377\244\236\223\377\243\235\222\377\243\235\221\377\243\235\222"
+  "\377\241\234\220\377\242\234\220\377\241\234\220\377\242\234\220\377"
+  "\241\233\217\377\241\233\220\377\202\237\231\215\377\202\235\227\214"
+  "\377\5\233\226\212\377gcY\377\0\0\0\377\0\0\0.\0\0\0\11\220\0\0\0\0\10"
+  "\0\0\0\377\377\377\377\377\364\363\362\377\363\362\361\377\362\362\360"
+  "\377\0\0\0\377\377\377\377\377\347\346\343\377\202\346\345\342\377\1"
+  "\221\220\216\377\222\0\0\0\377\3\0\0\0}\0\0\0*\0\0\0\10\220\0\0\0\0\3"
+  "\0\0\0\377\377\377\377\377\360\360\356\377\202\357\357\355\377\3\0\0"
+  "\0\377\371\371\371\377\344\343\340\377\202kki\377\6jig\377ba_\377YXV"
+  "\377WWU\377WVT\377WWU\377\202VVT\377\11\265\264\261\377\264\262\257\377"
+  "\263\261\256\377\261\257\254\377\260\256\253\377\200{s\377\0\0\0\377"
+  "\0\0\0U\0\0\0""6\202\0\0\0/\3\0\0\0*\0\0\0\27\0\0\0\4\220\0\0\0\0\33"
+  "\0\0\0\377\377\377\377\377\355\355\353\377poo\377oon\377\0\0\0\377\355"
+  "\355\355\377\341\340\335\377\341\337\334\377\341\340\334\377\340\337"
+  "\333\377\336\335\331\377\330\330\324\377\331\330\324\377\330\327\323"
+  "\377\331\330\324\377\327\326\322\377\330\326\322\377\325\323\317\377"
+  "\324\322\316\377\321\317\313\377\320\316\311\377\317\315\311\377\227"
+  "\221\206\377\0\0\0\377\0\0\0""6\0\0\0\22\202\0\0\0\11\2\0\0\0\10\0\0"
+  "\0\4\221\0\0\0\0\3\0\0\0\377\377\377\377\377\353\352\350\377\202\351"
+  "\350\346\377\13\0\0\0\377\321\321\321\377\341\337\333\377\340\336\332"
+  "\377\337\336\332\377\336\335\331\377\340\337\333\377\336\335\331\377"
+  "\340\336\332\377\336\335\331\377\340\336\332\377\202\336\334\330\377"
+  "\202\334\332\326\377\7\330\326\322\377\327\326\321\377\325\323\316\377"
+  "\233\225\212\377\0\0\0\377\0\0\0/\0\0\0\11\225\0\0\0\0\3\0\0\0\377\377"
+  "\377\377\377\347\346\343\377\202mlk\377\15\0\0\0\377\231\230\221\377"
+  "\243\236\222\377\244\236\223\377\243\235\222\377\243\235\221\377\243"
+  "\235\222\377\241\234\220\377\242\234\220\377\241\234\220\377\242\234"
+  "\220\377\241\233\217\377\241\233\220\377\202\237\231\215\377\202\235"
+  "\227\214\377\5\233\226\212\377gcY\377\0\0\0\377\0\0\0.\0\0\0\11\225\0"
+  "\0\0\0\6\0\0\0\377\371\371\371\377\344\343\340\377\343\342\337\377\343"
+  "\342\336\377\217\216\214\377\222\0\0\0\377\3\0\0\0}\0\0\0*\0\0\0\10\225"
+  "\0\0\0\0\26\0\0\0\377\355\355\355\377\341\340\335\377\341\337\334\377"
+  "\341\340\334\377\334\333\327\377\315\314\311\377\273\272\266\377\267"
+  "\266\263\377\266\265\262\377\267\266\263\377\265\265\261\377\266\265"
+  "\261\377\264\262\257\377\263\261\256\377\261\257\254\377\260\256\252"
+  "\377\257\255\252\377\200{q\377\0\0\0\377\0\0\0U\0\0\0""6\202\0\0\0/\3"
+  "\0\0\0*\0\0\0\27\0\0\0\4\225\0\0\0\0\13\0\0\0\377\321\321\321\377\341"
+  "\337\333\377\340\336\332\377\337\336\332\377\336\335\331\377\334\333"
+  "\327\377\327\326\322\377\330\326\322\377\326\325\321\377\330\326\322"
+  "\377\202\326\324\320\377\202\324\322\316\377\7\320\316\312\377\317\316"
+  "\311\377\315\313\306\377\225\217\205\377\0\0\0\377\0\0\0""6\0\0\0\22"
+  "\202\0\0\0\11\2\0\0\0\10\0\0\0\4\226\0\0\0\0\15\0\0\0\377\231\230\221"
+  "\377\243\236\222\377\244\236\223\377\243\235\222\377\243\235\221\377"
+  "\243\235\222\377\241\234\220\377\242\234\220\377\241\234\220\377\242"
+  "\234\220\377\241\233\217\377\241\233\220\377\202\237\231\215\377\202"
+  "\235\227\214\377\5\233\226\212\377gcY\377\0\0\0\377\0\0\0.\0\0\0\11\232"
+  "\0\0\0\0\1\0\0\0^\222\0\0\0\377\3\0\0\0}\0\0\0*\0\0\0\10\232\0\0\0\0"
+  "\3\0\0\0\4\0\0\0\27\0\0\0*\220\0\0\0/\3\0\0\0*\0\0\0\27\0\0\0\4\233\0"
+  "\0\0\0\2\0\0\0\4\0\0\0\10\220\0\0\0\11\2\0\0\0\10\0\0\0\4\377\0\0\0\0"
+  "\377\0\0\0\0\345\0\0\0\0"};
